@@ -66,6 +66,15 @@ public interface ICodeCompletionASTManager {
      */
     public abstract IPythonNature getNature();
 
+    public static class ImportInfo{
+        public String importsTipperStr;
+        public boolean hasImportSubstring;
+        public ImportInfo(String importsTipperStr, boolean hasImportSubstring){
+            this.importsTipperStr = importsTipperStr;
+            this.hasImportSubstring = hasImportSubstring;
+        }
+    }
+
     //----------------------------------- COMPLETIONS
 
     /**
@@ -74,7 +83,7 @@ public interface ICodeCompletionASTManager {
      * @param initial: this is the initial module (e.g.: foo.bar) or an empty string.
      * @return a Set with the imports as tuples with the name, the docstring.
      */
-    public abstract IToken[] getCompletionsForImport(final String original, ICompletionRequest request);
+    public abstract IToken[] getCompletionsForImport(ImportInfo original, ICompletionRequest request);
 
 
     /**
@@ -109,9 +118,10 @@ public interface ICodeCompletionASTManager {
     /**
      * @return tuple with:
      * 0: mod
-     * 1: tok
+     * 1: tok (string)
+     * 2: actual tok
      */
-    public abstract Tuple<IModule, String> findOnImportedMods( IPythonNature nature, String activationToken, IModule current);
+    public abstract Tuple3<IModule, String, IToken> findOnImportedMods( IPythonNature nature, String activationToken, IModule current);
 
     /**
      * This function tries to find some activation token defined in some imported module.  
@@ -126,9 +136,10 @@ public interface ICodeCompletionASTManager {
      * the TestCase is put as the module
      * 
      * 0: mod
-     * 1: tok
+     * 1: tok (string)
+     * 2: actual tok
      */
-    public abstract Tuple<IModule, String> findOnImportedMods( IToken[] importedModules, IPythonNature nature, String activationToken, String currentModuleName);
+    public abstract Tuple3<IModule, String, IToken> findOnImportedMods( IToken[] importedModules, IPythonNature nature, String activationToken, String currentModuleName);
     
     /**
      * Finds the tokens on the given imported modules
@@ -166,6 +177,7 @@ public interface ICodeCompletionASTManager {
      * @param line
      */
     public abstract IToken[] getCompletionsForModule(IModule module, ICompletionState state, boolean searchSameLevelMods);
+    public abstract IToken[] getCompletionsForModule(IModule module, ICompletionState state, boolean searchSameLevelMods, boolean lookForArgumentCompletion);
 
     /**
      * This method gets the completions for a wild import. 
@@ -204,6 +216,23 @@ public interface ICodeCompletionASTManager {
     public abstract List getGlobalCompletions(IToken[] globalTokens, IToken[] importedModules, IToken[] wildImportedModules, ICompletionState state, IModule current);
 
 
+    /**
+     * Get the actual token representing the tokName in the passed module  
+     * @param module the module where we're looking
+     * @param tokName the name of the token we're looking for
+     * @param nature the nature we're looking for
+     * @return the actual token in the module (or null if it was not possible to find it).
+     */
+    public IToken getRepInModule(IModule module, String tokName, IPythonNature nature);
     
+    /**
+     * This method gathers an IToken correspondent to the actual token for some import
+     * 
+     * @param state the current completion state
+     * @param imported the token generated from an ImportFrom 
+     * @return the IToken: the actual token that generated that import or the import passed if we weren't
+     * able to find its actual definition
+     */
+    public IToken resolveImport(ICompletionState state, IToken imported);
 
 }
\ No newline at end of file
