@@ -24,6 +24,11 @@ public interface IInterpreterManager {
      */
     public String JYTHON_INTERPRETER_PATH = "JYTHON_INTERPRETER_PATH";
     
+    /**
+     * This is the constant from where we get the jython cache dir
+     */
+    public String JYTHON_CACHE_DIR = "JYTHON_CACHE_DIR";
+    
     /**
      * This is not applicable for jython (the interpreter is given by the java plugin - jdt)
      * 
@@ -131,5 +136,11 @@ public interface IInterpreterManager {
      * @return IPythonNature.PYTHON_RELATED or IPythonNature.JYTHON_RELATED 
      */
     public int getRelatedId();
+
+    /**
+     * @param interpreter the interpreter we care about
+     * @return whether the interpreter has information on this manager.
+     */
+    public boolean hasInfoOnInterpreter(String interpreter);
     
 }
