@@ -12,12 +12,16 @@ import org.eclipse.core.runtime.IProgressMonitor;
 /**
  * @author Fabio
  */
-public interface IPythonNature extends IProjectNature{
+public interface IPythonNature extends IProjectNature, IGrammarVersionProvider{
 
+    /**
+     * Constants persisted
+     */
     public static final String PYTHON_VERSION_2_3 = "python 2.3";
     public static final String PYTHON_VERSION_2_4 = "python 2.4";
+    public static final String PYTHON_VERSION_2_5 = "python 2.5";
     public static final String JYTHON_VERSION_2_1 = "jython 2.1";
-
+    
     /**
      * this id is provided so that we can have an identifier for python-related things (independent of its version)
      */
