@@ -27,6 +27,24 @@ public class Tuple<X ,Y> implements Serializable{
         }
         
         Tuple t2 = (Tuple) obj;
+        if(o1 == t2.o1 && o2 == t2.o2){ //all the same 
+        	return true;
+        }
+        
+    	if(o1 == null && t2.o1 != null){
+    		return false;
+    	}
+    	if(o2 == null && t2.o2 != null){
+    		return false;
+    	}
+    	if(o1 != null && t2.o1 == null){
+    		return false;
+    	}
+    	if(o2 != null && t2.o2 == null){
+    		return false;
+    	}
+        
+        
         if(!o1.equals(t2.o1)){
             return false;
         }
@@ -38,7 +56,16 @@ public class Tuple<X ,Y> implements Serializable{
     
     @Override
     public int hashCode() {
-        return o1.hashCode() * o2.hashCode();
+    	if(o1 != null && o2 != null){
+    		return o1.hashCode() * o2.hashCode();
+    	}
+    	if(o1 != null){
+    		return o1.hashCode();
+    	}
+    	if(o2 != null){
+    		return o2.hashCode();
+    	}
+    	return 7;
     }
     
     @Override
