@@ -1,11 +1,11 @@
 import sys
 import os
+import test_pydevdio #@UnresolvedImport - importing itself
 
 #make it as if we were executing from the directory above this one (so that we can use jycompletionserver
 #without the need for it being in the pythonpath)
-sys.argv[0] = os.path.dirname(sys.argv[0]) 
-#twice the dirname to get the previous level from this file.
-sys.path.insert(1, os.path.join(  os.path.dirname( sys.argv[0] )) )
+#(twice the dirname to get the previous level from this file.)
+sys.path.insert(1, os.path.join(  os.path.dirname(os.path.dirname( test_pydevdio.__file__ )) ))
 
 import unittest
 
@@ -29,4 +29,6 @@ class Test(unittest.TestCase):
             sys.stdout = original
         
 if __name__ == '__main__':
-    unittest.main()
+    #this is so that we can run it frem the jython tests -- because we don't actually have an __main__ module
+    #(so, it won't try importing the __main__ module)
+    unittest.TextTestRunner().run(unittest.makeSuite(Test))
