@@ -22,6 +22,7 @@ public interface Constants {
 	static final String ID_PYTHON_REGULAR_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.regularLaunchConfigurationType";
 	static final String ID_PYTHON_COVERAGE_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.coverageLaunchConfigurationType";
 	static final String ID_PYTHON_UNITTEST_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.unittestLaunchConfigurationType";
+	static final String ID_JYTHON_UNITTEST_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.jythonUnittestLaunchConfigurationType";
 	static final String ID_JYTHON_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.jythonLaunchConfigurationType";
 	static final String PROCESS_TYPE = "PYDEV.PYTHON";
 	
@@ -35,6 +36,7 @@ public interface Constants {
 	static final String ATTR_PROGRAM_ARGUMENTS = "org.eclipse.ui.externaltools" + ".ATTR_TOOL_ARGUMENTS";
 
 	static final String ATTR_INTERPRETER = PLUGIN_ID + ".ATTR_INTERPRETER";
+	static final String ATTR_INTERPRETER_DEFAULT = "__default"; //$NO-NLS-1$; 
 	static final String ATTR_PROJECT = PLUGIN_ID + ".ATTR_PROJECT";
 	static final String ATTR_RESOURCE_TYPE = PLUGIN_ID + ".ATTR_RESOURCE_TYPE";
 	
