@@ -23,17 +23,19 @@ import org.eclipse.jface.text.IDocumentListener;
 import org.eclipse.ui.IEditorInput;
 import org.eclipse.ui.IFileEditorInput;
 import org.python.pydev.core.ExtensionHelper;
+import org.python.pydev.core.IGrammarVersionProvider;
 import org.python.pydev.core.IPyEdit;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.Tuple;
 import org.python.pydev.core.docutils.DocUtils;
 import org.python.pydev.core.docutils.PySelection;
 import org.python.pydev.core.log.Log;
+import org.python.pydev.parser.grammar24.PythonGrammar24;
+import org.python.pydev.parser.grammar25.PythonGrammar25;
 import org.python.pydev.parser.jython.CharStream;
 import org.python.pydev.parser.jython.FastCharStream;
 import org.python.pydev.parser.jython.IParserHost;
 import org.python.pydev.parser.jython.ParseException;
-import org.python.pydev.parser.jython.PythonGrammar;
 import org.python.pydev.parser.jython.ReaderCharStream;
 import org.python.pydev.parser.jython.SimpleNode;
 import org.python.pydev.parser.jython.TokenMgrError;
@@ -51,6 +53,7 @@ import org.python.pydev.parser.jython.ast.commentType;
  */
 
 public class PyParser {
+
     /**
      * just for tests, when we don't have any editor
      */
@@ -111,10 +114,16 @@ public class PyParser {
      */
     private int elapseMillisBeforeAnalysis;
     
+    /**
+     * This is the version of the grammar that should be used for this parser
+     */
+    private IGrammarVersionProvider grammarVersionProvider;
+
     /**
      * should only be called for testing. does not register as a thread
      */
-    public PyParser() {
+    public PyParser(IGrammarVersionProvider grammarVersionProvider) {
+        this.grammarVersionProvider = grammarVersionProvider;
         parserListeners = new ArrayList<IParserObserver>();
         scheduler = new ParserScheduler(this);
 
@@ -146,7 +155,7 @@ public class PyParser {
      * @param editorView
      */
     public PyParser(IPyEdit editorView) {
-        this();
+        this(editorView.getPythonNature());
         this.editorView = editorView;
     }
 
@@ -290,7 +299,7 @@ public class PyParser {
     public Tuple<SimpleNode, Throwable> reparseDocument(Object ... argsToReparse) {
         
         //get the document ast and error in object
-        Tuple<SimpleNode, Throwable> obj = reparseDocument(new ParserInfo(document, true, -1));
+        Tuple<SimpleNode, Throwable> obj = reparseDocument(new ParserInfo(document, true, grammarVersionProvider.getGrammarVersion()));
         
         IFile original = null;
         IAdaptable adaptable = null;
@@ -360,18 +369,16 @@ public class PyParser {
         public List<Integer> linesChanged = new ArrayList<Integer>();
         public ParseException parseErr;
         public boolean tryReparse = TRY_REPARSE;
+        public int grammarVersion;
         
-        public ParserInfo(IDocument document, boolean changedCurrentLine){
-            this(document, changedCurrentLine, null);
+        public ParserInfo(IDocument document, boolean changedCurrentLine, int grammarVersion){
+            this.document = document;
+            this.stillTryToChangeCurrentLine = changedCurrentLine;
+            this.grammarVersion = grammarVersion;
         }
         
         public ParserInfo(IDocument document, boolean changedCurrentLine, IPythonNature nature){
-            this.document = document;
-            this.stillTryToChangeCurrentLine = changedCurrentLine;
-        }
-
-        public ParserInfo(IDocument document, boolean changedCurrentLine, int currentLine){
-            this(document, changedCurrentLine, null, currentLine);
+            this(document, changedCurrentLine, nature.getGrammarVersion());
         }
         
         public ParserInfo(IDocument document, boolean changedCurrentLine, IPythonNature nature, int currentLine){
@@ -399,24 +406,33 @@ public class PyParser {
         } catch (Exception e) {
             throw new RuntimeException(e);
         }
-        String initialDoc = newDoc.get();
         
         
         CharStream in = null;
         if(USE_FAST_STREAM){
-        	in = new FastCharStream(initialDoc);
+            //we don't want to keep the string from being released, so, just get the char array from the string
+            char[] cs = newDoc.get().toCharArray();
+        	in = new FastCharStream(cs);
         }else{
         	//this should be deprecated in the future (it is still here so that we can evaluate
         	//the changes done by the change of the reader).
+            String initialDoc = newDoc.get();
 	        StringReader inString = new StringReader(initialDoc);
 	        in = new ReaderCharStream(inString);
+            throw new RuntimeException("This char stream reader was deprecated (was maintained only for testing purposes).");
         }
         
         IParserHost host = new CompilerAPI();
-        PythonGrammar grammar = null;
+        IGrammar grammar = null;
+        if(info.grammarVersion == IPythonNature.GRAMMAR_PYTHON_VERSION_2_4){
+            grammar = new PythonGrammar24(in, host);
+        }else if(info.grammarVersion == IPythonNature.GRAMMAR_PYTHON_VERSION_2_5){
+            grammar = new PythonGrammar25(in, host);
+        }else{
+            throw new RuntimeException("The grammar specified for parsing is not valid: "+info.grammarVersion);
+        }
 
         try {
-        	grammar = new PythonGrammar(in, host);
         	
         	if(ENABLE_TRACING){
         		//grammar has to be generated with debugging info for this to make a difference
