@@ -42,6 +42,19 @@ public class NodeUtils {
      * @return a string with the representation of the parameters of the function
      */
     public static String getNodeArgs(SimpleNode node) {
+        if(node instanceof ClassDef){
+            ClassDef c = (ClassDef) node;
+            for(stmtType t: c.body){
+                if(t instanceof FunctionDef){
+                    FunctionDef def = (FunctionDef) t;
+                    if(((NameTok)def.name).id.equals("__init__")){
+                        node = def;
+                        break; //keep going to get the arguments of the __init__
+                    }
+                }
+            }
+        }
+        
         if(node instanceof FunctionDef){
             FunctionDef f = (FunctionDef)node;
             
@@ -227,6 +240,10 @@ public class NodeUtils {
     
     
     public static String getFullRepresentationString(SimpleNode node) {
+        return getFullRepresentationString(node, false);
+    }
+    
+    public static String getFullRepresentationString(SimpleNode node, boolean fullOnSubscriptOrCall) {
     	if (node instanceof Dict){
     		return "dict";
     	}
@@ -261,13 +278,22 @@ public class NodeUtils {
         	StringBuffer buf = new StringBuffer();
         	for (Object part : attributeParts) {
 				if(part instanceof Call){
-					//stop on a call (that's what we usually want, since the end will depend on the things that 
-					//return from the call).
-					return buf.toString();
+                    //stop on a call (that's what we usually want, since the end will depend on the things that 
+                    //return from the call).
+				    if(!fullOnSubscriptOrCall){
+				        return buf.toString();
+                    }else{
+                        buf.append("()");//call
+                    }
 					
 				}else if (part instanceof Subscript){
-					//stop on a subscript : e.g.: in bb.cc[10].d we only want the bb.cc part
-		            return getFullRepresentationString(((Subscript)part).value);
+				    if(!fullOnSubscriptOrCall){
+				        //stop on a subscript : e.g.: in bb.cc[10].d we only want the bb.cc part
+				        return getFullRepresentationString(((Subscript)part).value);
+                    }else{
+                        buf.append(getFullRepresentationString(((Subscript)part).value));
+                        buf.append("[]");//subscript access
+                    }
 
 				}else{
 					//otherwise, just add another dot and keep going.
@@ -466,16 +492,16 @@ public class NodeUtils {
             return "str";
             
             
-        } else if(tok.endsWith("]")){
+        } else if(tok.endsWith("]") && tok.startsWith("[")){
             //ok, we are getting code completion for a list.
             return "list";
             
             
-        } else if(tok.endsWith("}")){
+        } else if(tok.endsWith("}") && tok.startsWith("{")){
             //ok, we are getting code completion for a dict.
             return "dict";
             
-        } else if(tok.endsWith(")")){
+        } else if(tok.endsWith(")") && tok.startsWith("(")){
             //ok, we are getting code completion for a tuple.
             return "tuple";
             
