@@ -1,6 +1,6 @@
 package org.python.pydev.parser.visitors.scope;
 
-import org.python.parser.SimpleNode;
+import org.python.pydev.parser.jython.SimpleNode;
 
 public class SequencialASTIteratorVisitor extends EasyAstIteratorBase{
 
@@ -22,6 +22,6 @@ public class SequencialASTIteratorVisitor extends EasyAstIteratorBase{
         }
         return visitor;
     }
-
+    
 
 }
