@@ -7,6 +7,7 @@ import java.io.File;
 import java.util.List;
 
 import org.eclipse.jface.text.Document;
+import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.REF;
 import org.python.pydev.core.TestDependent;
 import org.python.pydev.parser.jython.SimpleNode;
@@ -24,7 +25,7 @@ public class PyParserTest extends PyParserTestBase{
         try {
             PyParserTest test = new PyParserTest();
             test.setUp();
-            test.testParser12();
+            test.testYield2();
             test.tearDown();
             System.out.println("Finished");
             junit.textui.TestRunner.run(PyParserTest.class);
@@ -89,12 +90,51 @@ public class PyParserTest extends PyParserTestBase{
     }
     
     
+    public void testEmptyBaseForClass() {
+        String s = "" +
+        "class B2(): pass\n" +
+        "\n" +
+        "";
+        parseLegalDocStr(s);
+    }
+    public void testFor2() {
+        String s = "" +
+        "[x for x in 1,2,3,4]\n" +
+        "";
+        parseLegalDocStr(s);
+    }
+    public void testFor2a() {
+        String s = "" +
+        "[x for x in 2,3,4 if x > 2]\n" +
+        "";
+        parseLegalDocStr(s);
+    }
+    
+    public void testFor3() {
+        String s = "" +
+        "[x() for x in lambda: True, lambda: False if x() ] \n" +
+        "";
+        parseLegalDocStr(s);
+    }
+    
+    
     public void testYield() {
         String s = "" +
                 "def m():\n" +
                 "    yield 1";
         parseLegalDocStr(s);
     }
+    
+    public void testYield2() {
+        setDefaultVersion(IPythonNature.GRAMMAR_PYTHON_VERSION_2_4);
+    	String s = "" +
+    	"class Generator:\n" +
+    	"    def __iter__(self): \n" +
+    	"        for a in range(10):\n" +
+    	"            yield foo(a)\n" +
+    	"";
+    	parseLegalDocStr(s);
+    }
 
     
     public void testDecorator() {
@@ -189,7 +229,7 @@ public class PyParserTest extends PyParserTestBase{
      * @param file
      */
     private void parseFilesInDir(File file) {
-        assertTrue(file.exists());
+        assertTrue("Directory "+file+" does not exist", file.exists());
         assertTrue(file.isDirectory());
         File[] files = file.listFiles();
         for (int i = 0; i < files.length; i++) {
@@ -200,16 +240,61 @@ public class PyParserTest extends PyParserTestBase{
         }
     }
     
-    public void testOnCsv() {
-    	PyParser.USE_FAST_STREAM = false;
-    	String loc = TestDependent.PYTHON_LIB+"csv.py";
-    	String s = REF.getFileContents(new File(loc));
-    	parseLegalDocStr(s);
-    	
-    	PyParser.USE_FAST_STREAM = true;
-    	loc = TestDependent.PYTHON_LIB+"csv.py";
-    	s = REF.getFileContents(new File(loc));
-    	parseLegalDocStr(s);
+    
+//    not removed completely because we may still want to debug it later...
+//    public void testOnCsv() {
+//    	PyParser.USE_FAST_STREAM = false;
+//    	String loc = TestDependent.PYTHON_LIB+"csv.py";
+//    	String s = REF.getFileContents(new File(loc));
+//    	parseLegalDocStr(s);
+//    	
+//    	PyParser.USE_FAST_STREAM = true;
+//    	loc = TestDependent.PYTHON_LIB+"csv.py";
+//    	s = REF.getFileContents(new File(loc));
+//    	parseLegalDocStr(s);
+//    }
+    
+    
+    public void testOnCgiMod() {
+        String s = "dict((day, index) for index, daysRep in enumeratedDays for day in daysRep)";
+        parseLegalDocStr(s);
+    }
+    
+    public void testOnCgiMod2() {
+        String loc = TestDependent.PYTHON_LIB+"cgi.py";
+        String s = REF.getFileContents(new File(loc));
+        parseLegalDocStr(s);
+    }
+    
+//    this should really give errors (but is not a priority)
+//    public void testErrOnFor() {
+//        //ok, it should throw errors in those cases (but that's not so urgent)
+//        String s = "foo(x for x in range(10), 100)\n";
+//        parseILegalDoc(new Document(s));
+//        
+//        String s1 = "foo(100, x for x in range(10))\n";
+//        parseILegalDoc(new Document(s1));
+//        
+//    }
+    
+    public void testOnTestGrammar() {
+        String loc = TestDependent.PYTHON_LIB+"test/test_grammar.py";
+        String s = REF.getFileContents(new File(loc));
+        parseLegalDocStr(s,"(file: test_grammar.py)");
+    }
+    
+    public void testOnTestContextLib() {
+        if(TestDependent.HAS_PYTHON_TESTS){
+        	String loc = TestDependent.PYTHON_LIB+"test/test_contextlib.py";
+	        String s = REF.getFileContents(new File(loc));
+	        parseLegalDocStr(s,"(file: test_contextlib.py)");
+        }
+    }
+    
+    public void testOnCalendar() {
+        String loc = TestDependent.PYTHON_LIB+"hmac.py";
+        String s = REF.getFileContents(new File(loc));
+        parseLegalDocStr(s);
     }
     
     public void testOnUnittestMod() {
@@ -311,6 +396,12 @@ public class PyParserTest extends PyParserTestBase{
         parseLegalDocStr(s);
     }
     
+    public void testParser13() throws Exception {
+        String s = "plural = lambda : None";
+        parseLegalDocStr(s);
+        
+    }
+    
     public void testParser3() {
         String s = "print (x for x in y)";
         
