@@ -4,20 +4,43 @@ import junit.framework.TestCase;
 
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.IDocument;
+import org.python.pydev.core.IGrammarVersionProvider;
+import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.Tuple;
 import org.python.pydev.parser.jython.ParseException;
 import org.python.pydev.parser.jython.SimpleNode;
 import org.python.pydev.parser.jython.Token;
 
 public class PyParserTestBase extends TestCase {
-    protected PyParser parser;
+    protected static PyParser parser;
+    private static int defaultVersion;
+    private static IGrammarVersionProvider versionProvider = new IGrammarVersionProvider(){
+
+        public int getGrammarVersion() {
+            return defaultVersion;
+        }};
+
+    /**
+     * @param defaultVersion the defaultVersion to set
+     */
+    protected static void setDefaultVersion(int defaultVersion) {
+        PyParserTestBase.defaultVersion = defaultVersion;
+    }
+
+    /**
+     * @return the defaultVersion
+     */
+    protected static int getDefaultVersion() {
+        return defaultVersion;
+    }
 
     protected void setUp() throws Exception {
         PyParser.ACCEPT_NULL_EDITOR = true;
         PyParser.ENABLE_TRACING = true;
         PyParser.TRY_REPARSE = false;
         ParseException.verboseExceptions = true;
-        parser = new PyParser();
+        parser = new PyParser(versionProvider);
+        setDefaultVersion(IPythonNature.LATEST_GRAMMAR_VERSION);
         super.setUp();
     }
 
@@ -35,7 +58,8 @@ public class PyParserTestBase extends TestCase {
 	 */
 	protected static SimpleNode parseLegalDocStr(String s, Object ... additionalErrInfo) {
 	    Document doc = new Document(s);
-	    return parseLegalDoc(doc, additionalErrInfo, new PyParser());
+        //by default always use the last version for parsing
+	    return parseLegalDoc(doc, additionalErrInfo, parser);
 	}
 
 	protected SimpleNode parseLegalDoc(IDocument doc, Object[] additionalErrInfo) {
@@ -69,10 +93,11 @@ public class PyParserTestBase extends TestCase {
 	        }
 	        if (err instanceof ParseException) {
 	            ParseException parseErr = (ParseException) err;
+                parseErr.printStackTrace();
 	            
 	            Token token = parseErr.currentToken;
 	            if(token != null){
-	                fail("Expected no error, received: "+err+" "+s+" line:"+token.beginLine+ " col:"+token.beginColumn);
+	                fail("Expected no error, received: "+parseErr.getMessage()+" "+s+" line:"+token.beginLine+ " col:"+token.beginColumn);
 	            }
 	        }
 	         
