@@ -132,7 +132,10 @@ def GenerateTip( data ):
     return f,tips
     
     
-
+def CheckChar(c):
+    if c == '-' or c == '.':
+        return '_'
+    return c
 
 def GenerateImportsTipForModule( mod ):
     '''
@@ -162,22 +165,6 @@ def GenerateImportsTipForModule( mod ):
                 obj = getattr(mod, d)
                 retType = TYPE_BUILTIN
     
-                if inspect.ismethod(obj) or inspect.isbuiltin(obj) or inspect.isfunction(obj) or inspect.isroutine(obj):
-                    try:
-                        args, vargs, kwargs, defaults = inspect.getargspec( obj )
-                            
-                        r = ''
-                        for a in ( args ):
-                            if len( r ) > 0:
-                                r += ', '
-                            r += str( a )
-                        args = '(%s)' % (r)
-                    except TypeError:
-                        args = '()'
-    
-                    retType = TYPE_FUNCTION
-                
-                
                 #check if we have to get docs
                 getDoc = True
                 for class_ in dontGetDocsOn:
@@ -193,6 +180,72 @@ def GenerateImportsTipForModule( mod ):
                         doc = inspect.getdoc( obj )
                     except: #may happen on jython when checking java classes (so, just ignore it)
                         doc = ''
+                        
+                        
+                if inspect.ismethod(obj) or inspect.isbuiltin(obj) or inspect.isfunction(obj) or inspect.isroutine(obj):
+                    try:
+                        args, vargs, kwargs, defaults = inspect.getargspec( obj )
+                            
+                        r = ''
+                        for a in ( args ):
+                            if len( r ) > 0:
+                                r += ', '
+                            r += str( a )
+                        args = '(%s)' % (r)
+                    except TypeError:
+                        #ok, let's see if we can get the arguments from the doc
+                        args = '()'
+                        try:
+                            if len(doc) > 0:
+                                i = doc.find('->')
+                                if i < 0:
+                                    i = doc.find('\n')
+                                    if i < 0:
+                                        i = doc.find('\r')
+                                        
+                                        
+                                if i > 0:
+                                    s = doc[0:i]
+                                    s = s.strip()
+                                    
+                                    #let's see if we have a docstring in the first line
+                                    if s[-1] == ')':
+                                        start = s.find('(')
+                                        if start >= 0:
+                                            end = s.find('[')
+                                            if end <= 0:
+                                                end = len(s)
+                                            
+                                            args = s[start:end]
+                                            if not args[-1] == ')':
+                                                args += ')'
+
+                                            
+                                            #now, get rid of unwanted chars
+                                            l = len(args)-1
+                                            r = []
+                                            for i in range(len(args)):
+                                                if i == 0 or i == l:
+                                                    r.append(args[i])
+                                                else:
+                                                    r.append(CheckChar(args[i]))
+                                                    
+                                            args = ''.join(r)
+                                            
+                        except:
+                            pass
+    
+                    retType = TYPE_FUNCTION
+                    
+                elif inspect.isclass(obj):
+                    retType = TYPE_CLASS
+                    
+                elif inspect.ismodule(obj):
+                    retType = TYPE_IMPORT
+                    
+                else:
+                    retType = TYPE_ATTR
+                
                 
                 #add token and doc to return - assure only strings.
                 ret.append(   (d, doc, args, str(retType))   )
@@ -201,10 +254,25 @@ def GenerateImportsTipForModule( mod ):
                 ret.append(   (d, '', args, TYPE_BUILTIN_AS_STR)   )
             
         else: #getCompleteInfo == False
-        
-            #ok, no complete info, let's try to do this as fast and clean as possible
-            #so, no docs for this kind of information, only the signatures
-            ret.append(   (d, '', args, TYPE_BUILTIN_AS_STR)   )
+            try:
+                obj = getattr(mod, d)
+            except: #just ignore and get it without aditional info
+                ret.append(   (d, '', args, TYPE_BUILTIN_AS_STR)   )
+            else:
+                if inspect.ismethod(obj) or inspect.isbuiltin(obj) or inspect.isfunction(obj) or inspect.isroutine(obj):
+                    retType = TYPE_FUNCTION
+                    
+                elif inspect.isclass(obj):
+                    retType = TYPE_CLASS
+                    
+                elif inspect.ismodule(obj):
+                    retType = TYPE_IMPORT
+                    
+                else:
+                    retType = TYPE_ATTR
+                #ok, no complete info, let's try to do this as fast and clean as possible
+                #so, no docs for this kind of information, only the signatures
+                ret.append(   (d, '', args, retType)   )
             
     return ret
 
