@@ -25,9 +25,13 @@ class Test(unittest.TestCase):
         self.assertEquals('', ret[2])
 
     def testImports2(self):
-        tip = importsTipper.GenerateTip('OpenGL.GLUT')
-        self.assertIn('glutDisplayFunc', tip)
-        self.assertIn('glutInitDisplayMode', tip)
+        try:
+            tip = importsTipper.GenerateTip('OpenGL.GLUT')
+            self.assertIn('glutDisplayFunc', tip)
+            self.assertIn('glutInitDisplayMode', tip)
+        except RuntimeError, e:
+            if not 'Unable to import module' in str(e):
+                raise
         
     def testImports(self):
         '''
@@ -38,27 +42,43 @@ class Test(unittest.TestCase):
         
         tip = importsTipper.GenerateTip('wxPython.wx.wxApp')
         
-        tip = importsTipper.GenerateTip('qt')
-        self.assertIn('QWidget'        , tip)
-        self.assertIn('QDialog'        , tip)
-        
-        tip = importsTipper.GenerateTip('qt.QWidget')
-        self.assertIn('rect'           , tip)
-        self.assertIn('rect'           , tip)
-        self.assertIn('AltButton'      , tip)
-
-        tip = importsTipper.GenerateTip('qt.QWidget.AltButton')
-        self.assertIn('__xor__'      , tip)
-
-        tip = importsTipper.GenerateTip('qt.QWidget.AltButton.__xor__')
-        self.assertIn('__class__'      , tip)
+        try:
+            tip = importsTipper.GenerateTip('qt')
+            self.assertIn('QWidget'        , tip)
+            self.assertIn('QDialog'        , tip)
+            
+            tip = importsTipper.GenerateTip('qt.QWidget')
+            self.assertIn('rect'           , tip)
+            self.assertIn('rect'           , tip)
+            self.assertIn('AltButton'      , tip)
+    
+            tip = importsTipper.GenerateTip('qt.QWidget.AltButton')
+            self.assertIn('__xor__'      , tip)
+    
+            tip = importsTipper.GenerateTip('qt.QWidget.AltButton.__xor__')
+            self.assertIn('__class__'      , tip)
+        except RuntimeError, e:
+            if not 'Unable to import module' in str(e):
+                raise
         
         tip = importsTipper.GenerateTip('__builtin__')
+#        for t in tip[1]:
+#            print t
         self.assertIn('object'         , tip)
         self.assertIn('tuple'          , tip)
         self.assertIn('RuntimeError'   , tip)
         self.assertIn('RuntimeWarning' , tip)
+        t = self.assertIn('cmp' , tip)
+        self.assertEqual('(x, y)', t[2]) #args
         
+        t = self.assertIn('isinstance' , tip)
+        self.assertEqual('(object, class_or_type_or_tuple)', t[2]) #args
+        
+        t = self.assertIn('compile' , tip)
+        self.assertEqual('(source, filename, mode)', t[2]) #args
+        
+        t = self.assertIn('setattr' , tip)
+        self.assertEqual('(object, name, value)', t[2]) #args
         
         tip = importsTipper.GenerateTip('compiler') 
         self.assertArgs('parse', '(buf, mode)', tip)
@@ -94,10 +114,10 @@ class Test(unittest.TestCase):
         
 def suite():
     s = unittest.TestSuite()
-    s.addTest(Test("testImports2"))
+    s.addTest(Test("testImports"))
     unittest.TextTestRunner(verbosity=2).run(s)
 
 if __name__ == '__main__':
-#    suite()
-    unittest.main()
+    suite()
+#    unittest.main()
     
