@@ -22,6 +22,7 @@ import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.action.IStatusLineManager;
+import org.eclipse.jface.dialogs.ErrorDialog;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.text.Assert;
 import org.eclipse.jface.text.BadLocationException;
@@ -49,7 +50,6 @@ import org.eclipse.ui.texteditor.AbstractDecoratedTextEditorPreferenceConstants;
 import org.eclipse.ui.texteditor.DefaultRangeIndicator;
 import org.eclipse.ui.texteditor.IDocumentProvider;
 import org.eclipse.ui.texteditor.IEditorStatusLine;
-import org.eclipse.ui.texteditor.ITextEditorActionDefinitionIds;
 import org.eclipse.ui.texteditor.MarkerUtilities;
 import org.eclipse.ui.texteditor.TextOperationAction;
 import org.eclipse.ui.views.contentoutline.IContentOutlinePage;
@@ -59,10 +59,12 @@ import org.python.pydev.core.ExtensionHelper;
 import org.python.pydev.core.IPyEdit;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.REF;
+import org.python.pydev.core.Tuple;
 import org.python.pydev.core.docutils.PyPartitionScanner;
 import org.python.pydev.core.docutils.PySelection;
 import org.python.pydev.editor.actions.OfflineAction;
 import org.python.pydev.editor.actions.OfflineActionTarget;
+import org.python.pydev.editor.actions.PyAction;
 import org.python.pydev.editor.actions.PyOpenAction;
 import org.python.pydev.editor.autoedit.IIndentPrefs;
 import org.python.pydev.editor.autoedit.PyAutoIndentStrategy;
@@ -82,7 +84,9 @@ import org.python.pydev.parser.visitors.scope.ASTEntry;
 import org.python.pydev.plugin.PydevPlugin;
 import org.python.pydev.plugin.PydevPrefs;
 import org.python.pydev.plugin.nature.PythonNature;
+import org.python.pydev.plugin.nature.SystemPythonNature;
 import org.python.pydev.ui.ColorCache;
+import org.python.pydev.ui.NotConfiguredInterpreterException;
 
 /**
  * The TextWidget.
@@ -463,6 +467,9 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
     protected void doSetInput(IEditorInput input) throws CoreException {
         super.doSetInput(input);
         IDocument document = getDocument(input);
+        //see if we have to change the encoding of the file on load
+        fixEncoding(input, document);
+
         checkAndCreateParserIfNeeded();
         if(document != null){
             parser.setDocument(document);
@@ -517,6 +524,7 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
                         new Job("Change encoding") {
 
                             protected IStatus run(IProgressMonitor monitor) {
+                                System.out.println("Changing Encoding");
                                 try {
                                     file.setCharset(encoding, monitor);
                                     ((TextFileDocumentProvider) getDocumentProvider()).setEncoding(input, encoding);
@@ -648,6 +656,7 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
         
         action.setActionDefinitionId(SIMPLEASSIST_PROPOSAL_ID);
         setAction(SIMPLEASSIST_PROPOSAL_ID, action); //$NON-NLS-1$ 
+        setActivationCodeToSimpleCompletion();
         
         
         
@@ -662,21 +671,9 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
         setAction(CONTENTASSIST_PROPOSAL_ID, action);
         // Tell the editor to execute this action
         // when Ctrl+Spacebar is pressed
-        setActionActivationCode(CONTENTASSIST_PROPOSAL_ID, ' ', -1, SWT.CTRL);
+        setActivationCodeToDefaultCompletion();
 
         
-        
-        // ---------------------------------------------------------------------------------
-        //template proposals
-        action = new TextOperationAction(resources, "TemplateProposals", this, ISourceViewer.CONTENTASSIST_PROPOSALS);
-
-        action.setActionDefinitionId(ITextEditorActionDefinitionIds.CONTENT_ASSIST_PROPOSALS);
-        setAction(TEMPLATE_PROPOSALS_ID, action);
-        markAsStateDependentAction(TEMPLATE_PROPOSALS_ID, true);
-
-        
-        
-        
         // ----------------------------------------------------------------------------------------
         //open action
         IAction openAction = new PyOpenAction();
@@ -695,6 +692,22 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
         notifier.notifyOnCreateActions(resources);
     }
 
+    /**
+     * Used so that Ctrl+Space is binded to the simple assist
+     */
+    public void setActivationCodeToSimpleCompletion() {
+        removeActionActivationCode(CONTENTASSIST_PROPOSAL_ID);
+        setActionActivationCode(SIMPLEASSIST_PROPOSAL_ID, ' ', -1, SWT.CTRL);
+    }
+
+    /**
+     * Used so that Ctrl+Space is binded to the default assist
+     */
+    public void setActivationCodeToDefaultCompletion() {
+        removeActionActivationCode(SIMPLEASSIST_PROPOSAL_ID);
+        setActionActivationCode(CONTENTASSIST_PROPOSAL_ID, ' ', -1, SWT.CTRL);
+    }
+
 
     protected void initializeKeyBindingScopes() {
         setKeyBindingScopes(new String[] { "org.python.pydev.ui.editor.scope" }); //$NON-NLS-1$
@@ -989,7 +1002,16 @@ public class PyEdit extends PyEditProjection implements IPyEdit {
         IProject project = getProject();
         IPythonNature pythonNature = PythonNature.getPythonNature(project);
         if(pythonNature == null){
-            pythonNature = PydevPlugin.getInfoForFile(getEditorFile()).o1;
+            Tuple<SystemPythonNature, String> infoForFile = PydevPlugin.getInfoForFile(getEditorFile());
+            if(infoForFile == null){
+                NotConfiguredInterpreterException e = new NotConfiguredInterpreterException();
+                ErrorDialog.openError(PyAction.getShell(), 
+                        "Error: no interpreter configured", "Interpreter not configured\n(Please, Configure it under window->preferences->PyDev)", 
+                        PydevPlugin.makeStatus(IStatus.ERROR, e.getMessage(), e));
+                throw e;
+                
+            }
+            pythonNature = infoForFile.o1;
         }
         return pythonNature;
     }
