@@ -8,6 +8,7 @@ package org.python.pydev.editor.actions.refactoring;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.text.BadLocationException;
+import org.python.pydev.editor.refactoring.IPyRefactoring;
 
 /**
  * @author Fabio Zadrozny
@@ -27,12 +28,24 @@ public class PyExtractLocalVariable extends PyRefactorAction {
     protected String perform(IAction action, String name, Operation operation) throws BadLocationException, CoreException {
         String res = "";
         if(name.equals("") == false){
-            res = getPyRefactoring("canExtractLocalVariable").extractLocalVariable(getRefactoringRequest(name, operation));
+            res = getPyRefactoring().extractLocalVariable(getRefactoringRequest(name, operation));
         }
         return res;
 
     }
     
+
+    IPyRefactoring pyRefactoring;
+    /**
+     * @return
+     */
+    protected IPyRefactoring getPyRefactoring() {
+        if(pyRefactoring == null){
+            pyRefactoring = getPyRefactoring("canExtractLocalVariable"); 
+        }
+        return pyRefactoring;
+    }
+
     protected String getInputMessage() {
         return "Please inform the new name.";
     }
