@@ -6,7 +6,7 @@
 package org.python.pydev.editor.actions.refactoring;
 
 import org.eclipse.jface.action.IAction;
-import org.python.pydev.editor.refactoring.AbstractPyRefactoring;
+import org.python.pydev.editor.refactoring.IPyRefactoring;
 
 /**
  * @author Fabio Zadrozny
@@ -20,14 +20,24 @@ public class PyRename extends PyRefactorAction {
      */
     protected String perform(IAction action, String name, Operation operation) throws Exception {
         String res = "";
-        if(name.equals("") == false){
-	        res = getPyRefactoring("canRename").rename(getRefactoringRequest(name, operation));
-        }
+        pyRefactoring = getPyRefactoring();
+        res = pyRefactoring.rename(getRefactoringRequest(name, operation));
         return res;
     }
 
+    IPyRefactoring pyRefactoring;
+    /**
+     * @return
+     */
+    protected IPyRefactoring getPyRefactoring() {
+        if(pyRefactoring == null){
+            pyRefactoring = getPyRefactoring("canRename"); 
+        }
+        return pyRefactoring;
+    }
+
     protected String getInputMessage() {
-        return "Please inform the new name.";
+        return "New value?";
     }
 
     /**
