@@ -349,7 +349,9 @@ public class PyAutoIndentStrategy implements IAutoEditStrategy{
                                 }
                             }
             			}else if(sizeExpected == sizeApplied){
-            				ps.deleteSpacesAfter(command.offset);
+                            if(command.length == 0){
+                				ps.deleteSpacesAfter(command.offset);
+                            }
             				command.text = txt;
             			}else if(sizeApplied > sizeExpected){
             				ps.deleteSpacesAfter(command.offset);
@@ -444,7 +446,7 @@ public class PyAutoIndentStrategy implements IAutoEditStrategy{
 	                String completeLine = ps.getLineWithoutCommentsOrLiterals();
 	                String lineToCursor = ps.getLineContentsToCursor().trim();
 	                if(completeLine.indexOf("import") == -1){
-	                    String importsTipperStr = PyCodeCompletion.getImportsTipperStr(lineToCursor, false);
+	                    String importsTipperStr = PyCodeCompletion.getImportsTipperStr(lineToCursor, false).importsTipperStr;
 	                    if(importsTipperStr.length() > 0){
 	                        command.text = " import ";
 	                    }
