@@ -12,6 +12,8 @@ import java.util.Collection;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.ListIterator;
+import java.util.Set;
 import java.util.StringTokenizer;
 
 import org.eclipse.core.runtime.CoreException;
@@ -28,15 +30,18 @@ import org.python.pydev.core.ICompletionState;
 import org.python.pydev.core.IModule;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.IToken;
+import org.python.pydev.core.ICodeCompletionASTManager.ImportInfo;
 import org.python.pydev.core.bundle.ImageCache;
 import org.python.pydev.core.docutils.DocUtils;
+import org.python.pydev.core.log.Log;
 import org.python.pydev.editor.codecompletion.revisited.ASTManager;
+import org.python.pydev.editor.codecompletion.revisited.AbstractToken;
 import org.python.pydev.editor.codecompletion.revisited.CompletionRecursionException;
 import org.python.pydev.editor.codecompletion.revisited.CompletionState;
 import org.python.pydev.editor.codecompletion.revisited.modules.AbstractModule;
 import org.python.pydev.editor.codecompletion.revisited.modules.CompiledModule;
 import org.python.pydev.editor.codecompletion.revisited.visitors.FindScopeVisitor;
-import org.python.pydev.editor.codecompletion.revisited.visitors.Scope;
+import org.python.pydev.editor.codecompletion.revisited.visitors.LocalScope;
 import org.python.pydev.editor.codecompletion.shell.AbstractShell;
 import org.python.pydev.parser.PyParser;
 import org.python.pydev.parser.jython.SimpleNode;
@@ -53,6 +58,15 @@ import org.python.pydev.ui.UIConstants;
  */
 public class PyCodeCompletion {
 
+    
+    /**
+     * This constant is used to debug the code-completion process on a production environment,
+     * so that we gather enough information about what's happening and the possible reasons
+     * for some bug (at this moment this is being specifically added because of a halting bug
+     * for pydev in linux: https://sourceforge.net/tracker/index.php?func=detail&aid=1509582&group_id=85796&atid=577329)
+     */
+    public static boolean DEBUG_CODE_COMPLETION = PyCodeCompletionPreferencesPage.isToDebugCodeCompletion();
+    
     /**
      * Type for unknown.
      */
@@ -160,8 +174,13 @@ public class PyCodeCompletion {
      * (This is where we do the "REAL" work).
      * @throws BadLocationException
      */
+    @SuppressWarnings("unchecked")
     public List getCodeCompletionProposals(ITextViewer viewer, CompletionRequest request) throws CoreException, BadLocationException {
-        
+        if(DEBUG_CODE_COMPLETION){
+            Log.toLogFile(this,"Starting getCodeCompletionProposals");
+            Log.addLogLevel();
+            Log.toLogFile(this,"Request:"+request);
+        }
         ArrayList ret = new ArrayList();
         try {
         	IPythonNature pythonNature = request.nature;
@@ -175,32 +194,39 @@ public class PyCodeCompletion {
 
             List theList = new ArrayList();
             try {
+                if(DEBUG_CODE_COMPLETION){
+                    Log.toLogFile(this,"AbstractShell.getServerShell");
+                }
                 if (CompiledModule.COMPILED_MODULES_ENABLED) {
                     AbstractShell.getServerShell(request.nature, AbstractShell.COMPLETION_SHELL); //just start it
                 }
+                if(DEBUG_CODE_COMPLETION){
+                    Log.toLogFile(this,"END AbstractShell.getServerShell");
+                }
             } catch (Exception e) {
                 throw new RuntimeException(e);
             }
 
             String trimmed = request.activationToken.replace('.', ' ').trim();
 
-            String importsTipper = getImportsTipperStr(request);
+            ImportInfo importsTipper = getImportsTipperStr(request);
 
             int line = request.doc.getLineOfOffset(request.documentOffset);
             IRegion region = request.doc.getLineInformation(line);
 
-            CompletionState state = new CompletionState(line, request.documentOffset - region.getOffset(), null, request.nature);
+            CompletionState state = new CompletionState(line, request.documentOffset - region.getOffset(), null, request.nature, request.qualifier);
+            state.isInCalltip = request.isInCalltip;
 
             boolean importsTip = false;
             //code completion in imports 
-            if (importsTipper.length() != 0) {
+            if (importsTipper.importsTipperStr.length() != 0) {
 
                 //get the project and make the code completion!!
                 //so, we want to do a code completion for imports...
                 //let's see what we have...
 
                 importsTip = true;
-                importsTipper = importsTipper.trim();
+                importsTipper.importsTipperStr = importsTipper.importsTipperStr.trim();
                 IToken[] imports = astManager.getCompletionsForImport(importsTipper, request);
                 theList.addAll(Arrays.asList(imports));
 
@@ -213,6 +239,7 @@ public class PyCodeCompletion {
                 
                 List completions = new ArrayList();
                 if (trimmed.equals("self") || trimmed.startsWith("self")) {
+                    state.setLookingForInstance(true);
                     getSelfCompletions(request, theList, state);
 
                 } else {
@@ -228,21 +255,60 @@ public class PyCodeCompletion {
             } else { //go to globals
 
                 state.activationToken = request.activationToken;
+                if(DEBUG_CODE_COMPLETION){
+                    Log.toLogFile(this,"astManager.getCompletionsForToken");
+                    Log.addLogLevel();
+                }
                 IToken[] comps = astManager.getCompletionsForToken(request.editorFile, request.doc, state);
+                if(DEBUG_CODE_COMPLETION){
+                    Log.remLogLevel();
+                    Log.toLogFile(this,"END astManager.getCompletionsForToken");
+                }
 
                 theList.addAll(Arrays.asList(comps));
                 
                 theList.addAll(getGlobalsFromParticipants(request, state));
             }
 
-            changeItokenToCompletionPropostal(viewer, request, ret, theList, importsTip);
+            Set<String> alreadyChecked = new HashSet<String>();
+            
+            for(ListIterator it=theList.listIterator(); it.hasNext();){
+                Object o = it.next();
+                if(o instanceof IToken){
+                    alreadyChecked.clear();
+                    IToken initialToken = (IToken) o;
+                    
+                    IToken token = initialToken;
+                    while(token.isImportFrom()){
+                        String strRep = token.toString();
+                        if(alreadyChecked.contains(strRep)){
+                            break;
+                        }
+                        alreadyChecked.add(strRep);
+                        
+                        IToken token2 = astManager.resolveImport(CompletionState.getEmptyCompletionState(token.getRepresentation(), request.nature), token);
+                        if(token2 != null && initialToken != token2){
+                            initialToken.setArgs(token2.getArgs());
+                            initialToken.setDocStr(token2.getDocStr());
+                            token = token2;
+                        }
+                    }
+                }
+            }
+            changeItokenToCompletionPropostal(viewer, request, ret, theList, importsTip, state.getIsLookingForInstance());
         } catch (CompletionRecursionException e) {
             ret.add(new CompletionProposal("",request.documentOffset,0,0,null,e.getMessage(), null,null));
         }
+        
+        if(DEBUG_CODE_COMPLETION){
+            Log.remLogLevel();
+            Log.toLogFile(this, "Finished completion. Returned:"+ret.size()+" completions.\r\n");
+        }
 
         return ret;
     }
 
+    @SuppressWarnings("unchecked")
     private Collection getGlobalsFromParticipants(CompletionRequest request, ICompletionState state) {
         ArrayList ret = new ArrayList();
         
@@ -294,7 +360,8 @@ public class PyCodeCompletion {
     /**
      * Get self completions when you already have a scope
      */
-    public static IToken[] getSelfCompletions(Scope scope, CompletionRequest request, List theList, CompletionState state, boolean getOnlySupers) throws BadLocationException {
+    @SuppressWarnings("unchecked")
+    public static IToken[] getSelfCompletions(LocalScope scope, CompletionRequest request, List theList, CompletionState state, boolean getOnlySupers) throws BadLocationException {
     	IToken[] comps = new IToken[0];
         while(scope.scope.size() > 0){
             SimpleNode node = (SimpleNode) scope.scope.pop();
@@ -338,7 +405,7 @@ public class PyCodeCompletion {
                         IModule module = AbstractModule.createModuleFromDoc("", null, request.doc, request.nature, line);
                       
                         ASTManager astMan = ((ASTManager)request.nature.getAstManager());
-                        comps = astMan.getAssignCompletions(module, new CompletionState(line, col, request.activationToken, request.nature));
+                        comps = astMan.getAssignCompletions(module, new CompletionState(line, col, request.activationToken, request.nature, request.qualifier));
 
                     }
                 }
@@ -350,31 +417,11 @@ public class PyCodeCompletion {
     }
 
     /**
-     * @param viewer 
-     * @param request
-     * @param convertedProposals
-     * @param iTokenList
-     * @param importsTip
+     * This is the place where we change the tokens we've gathered so far with the 'inference' engine and transform those
+     * tokens to actual completions as requested by the Eclipse infrastructure.
+     * @param lookingForInstance if looking for instance, we should not add the 'self' as parameter.
      */
-    private void changeItokenToCompletionPropostal(ITextViewer viewer, CompletionRequest request, List convertedProposals, List iTokenList, boolean importsTip) {
-        //TODO: check org.eclipse.jface.text.templates.TemplateCompletionProcessor to see how to do custom 'selections' in completions
-//        int offset = request.documentOffset;
-//        ITextSelection selection= (ITextSelection) viewer.getSelectionProvider().getSelection();
-//
-//        // adjust offset to end of normalized selection
-//        if (selection.getOffset() == offset)
-//            offset= selection.getOffset() + selection.getLength();
-//
-//        String prefix= extractPrefix(viewer, offset);
-//        Region region= new Region(offset - prefix.length(), prefix.length());
-//
-//        TemplateContextType contextType= getContextType(viewer, region);
-//        if (contextType != null) {
-//            IDocument document= viewer.getDocument();
-//            new DocumentTemplateContext(contextType, document, region.getOffset(), region.getLength());
-//        }
-
-        
+    private void changeItokenToCompletionPropostal(ITextViewer viewer, CompletionRequest request, List<ICompletionProposal> convertedProposals, List iTokenList, boolean importsTip, boolean lookingForInstance) {
         for (Iterator iter = iTokenList.iterator(); iter.hasNext();) {
             
             Object obj = iter.next();
@@ -388,11 +435,19 @@ public class PyCodeCompletion {
                 int l = name.length();
                 
                 String args = "";
-                if(! importsTip){
-	                args = getArgs(element);                
-	                if(args.length()>0){
-	                    l++; //cursor position is name + '('
-	                }
+                if(!importsTip ){
+                    boolean getIt = true;
+                    if(AbstractToken.isClassDef(element)){
+                        if(!request.isInCalltip){
+                            getIt=false;
+                        }
+                    }
+                    if(getIt){
+    	                args = getArgs(element, lookingForInstance);                
+    	                if(args.length()>0){
+    	                    l++; //cursor position is name + '('
+    	                }
+                    }
                 }
                 //END
                 
@@ -403,11 +458,26 @@ public class PyCodeCompletion {
                 if(type == PyCodeCompletion.TYPE_PARAM){
                     priority = IPyCompletionProposal.PRIORITY_LOCALS;
                 }
-                    
-                PyCompletionProposal proposal = new PyCompletionProposal(name+args,
-                        request.documentOffset - request.qlen, request.qlen, l, getImageForType(type), null, null, docStr, priority);
                 
+                int onApplyAction = PyCompletionProposal.ON_APPLY_DEFAULT;
+                if(request.isInCalltip){
+                    if(request.alreadyHasParams){
+                        onApplyAction = PyCompletionProposal.ON_APPLY_JUST_SHOW_CTX_INFO;
+                        
+                    }else{
+                        onApplyAction = PyCompletionProposal.ON_APPLY_SHOW_CTX_INFO_AND_ADD_PARAMETETRS;
+                    }
+                }
+                PyCalltipsContextInformation pyContextInformation = null;
+                if(args.length() > 2){
+                    String contextArgs = args.substring(1, args.length()-1); //remove the parentesis
+                    pyContextInformation = new PyCalltipsContextInformation(contextArgs, contextArgs, request);
+                }
+                PyCompletionProposal proposal = new PyLinkedModeCompletionProposal(name+args,
+                        request.documentOffset - request.qlen, request.qlen, l, getImageForType(type), null, 
+                        pyContextInformation, docStr, priority, onApplyAction, args);
                 convertedProposals.add(proposal);
+                    
             
             }else if(obj instanceof Object[]){
                 Object element[] = (Object[]) obj;
@@ -431,7 +501,7 @@ public class PyCodeCompletion {
                 
             }else if(obj instanceof ICompletionProposal){
                 //no need to convert
-                convertedProposals.add(obj);
+                convertedProposals.add((ICompletionProposal) obj);
             }
             
         }
@@ -441,10 +511,11 @@ public class PyCodeCompletion {
     
     /**
      * @param element
+     * @param lookingForInstance 
      * @param args
      * @return
      */
-    private String getArgs(IToken element) {
+    private String getArgs(IToken element, boolean lookingForInstance) {
         String args = "";
         if(element.getArgs().trim().length() > 0){
             StringBuffer buffer = new StringBuffer("(");
@@ -452,7 +523,7 @@ public class PyCodeCompletion {
 
             while(strTok.hasMoreTokens()){
                 String tok = strTok.nextToken();
-                if(tok.equals("self") == false){
+                if(!lookingForInstance || tok.equals("self") == false){
                     if(buffer.length() > 1){
                         buffer.append(", ");
                     }
@@ -480,15 +551,16 @@ public class PyCodeCompletion {
      * @return single space string if we are in imports but without any module
      *         string with current module (e.g. foo.bar.
      */
-    public String getImportsTipperStr(CompletionRequest request) {
+    public ImportInfo getImportsTipperStr(CompletionRequest request) {
         
         IDocument doc = request.doc;
         int documentOffset = request.documentOffset;
         
         return getImportsTipperStr(doc, documentOffset);
     }
+    
 
-    public static String getImportsTipperStr(IDocument doc, int documentOffset) {
+    public static ImportInfo getImportsTipperStr(IDocument doc, int documentOffset) {
         IRegion region;
         try {
             region = doc.getLineInformationOfOffset(documentOffset);
@@ -503,17 +575,18 @@ public class PyCodeCompletion {
     /**
      * @param doc
      * @param documentOffset
-     * @return
+     * @return the import info or null if none is available
      */
-    public static String getImportsTipperStr(String trimmedLine, boolean returnEvenEmpty) {
+    public static ImportInfo getImportsTipperStr(String trimmedLine, boolean returnEvenEmpty) {
         String importMsg = "";
         
         if(!trimmedLine.startsWith("from") && !trimmedLine.startsWith("import")){
-            return "";
+            return new ImportInfo("", false); //it is not an import
         }
         
         int fromIndex = trimmedLine.indexOf("from");
         int importIndex = trimmedLine.indexOf("import");
+        boolean foundImportOnArray = false;
 
         //check if we have a from or an import.
         if(fromIndex  != -1 || importIndex != -1){
@@ -523,18 +596,35 @@ public class PyCodeCompletion {
             if(fromIndex != -1 && importIndex == -1){
                 if(strings.length > 2){
                     //user has spaces as in  'from xxx uuu'
-                    return "";
+                    return new ImportInfo("", foundImportOnArray);
                 }
             }
             
-            
             for (int i = 0; i < strings.length; i++) {
+                if(strings[i].equals("import")){
+                    foundImportOnArray = true;
+                }
+                
                 if(strings[i].equals("from")==false && strings[i].equals("import")==false){
                     if(importMsg.length() != 0){
                         importMsg += '.';
                     }
                     importMsg += strings[i];
                 }
+                //now, if we have a from xxx import something, we'll always want to return only the xxx
+                if(fromIndex != -1 && importIndex == -1 && (foundImportOnArray || i == strings.length-1)){
+                    if(importMsg.length() == 0){
+                        return doExistingOrEmptyReturn(returnEvenEmpty, importMsg, foundImportOnArray);
+                    }
+                    if(importMsg.startsWith(".")){
+                        return new ImportInfo(importMsg, foundImportOnArray);
+                    }
+                    if(importMsg.indexOf(".") == -1){
+                        return doExistingOrEmptyReturn(returnEvenEmpty, importMsg, foundImportOnArray);
+                    }
+                    return new ImportInfo(importMsg.substring(0, importMsg.lastIndexOf(".")+1), foundImportOnArray);
+                    
+                }
             }
             
             if(fromIndex  != -1 && importIndex != -1){
@@ -543,37 +633,61 @@ public class PyCodeCompletion {
                 }
             }
         }else{
-            return "";
+            return new ImportInfo("", foundImportOnArray);
         }
         if (importMsg.indexOf(".") == -1){
-            if(returnEvenEmpty || importMsg.trim().length() > 0){
-                return " "; //we have only import fff or from iii (so, we're going for all imports).
-            }else{
-                return ""; //we have only import fff or from iii (so, we're going for all imports).
-            }
+            //we have only import fff or from iii (so, we're going for all imports).
+            return doExistingOrEmptyReturn(returnEvenEmpty, importMsg, foundImportOnArray);
         }
 
-        //now, we may still have something like 'unittest.test,' or 'unittest.test.,'
-        //so, we have to remove this comma (s).
-        int i;
-        while ( ( i = importMsg.indexOf(',')) != -1){
-            if(importMsg.charAt(i-1) == '.'){
-                int j = importMsg.lastIndexOf('.');
-                importMsg = importMsg.substring(0, j);
+        if(fromIndex == -1 && importMsg.indexOf(',') != -1){
+            //we have something like import xxx, yyy, ...
+            importMsg = importMsg.substring(importMsg.lastIndexOf(',')+1, importMsg.length());
+            if(importMsg.startsWith(".")){
+                importMsg = importMsg.substring(1);
             }
             
             int j = importMsg.lastIndexOf('.');
-            importMsg = importMsg.substring(0, j);
+            if(j != -1){
+                importMsg = importMsg.substring(0, j);
+                return new ImportInfo(importMsg, foundImportOnArray);
+            }else{
+                return doExistingOrEmptyReturn(returnEvenEmpty, importMsg, foundImportOnArray);
+            }
+            
+        }else{
+            //now, we may still have something like 'unittest.test,' or 'unittest.test.,'
+            //so, we have to remove this comma (s).
+            int i;
+            boolean removed = false;
+            while ( ( i = importMsg.indexOf(',')) != -1){
+                if(importMsg.charAt(i-1) == '.'){
+                    int j = importMsg.lastIndexOf('.');
+                    importMsg = importMsg.substring(0, j);
+                }
+                
+                int j = importMsg.lastIndexOf('.');
+                importMsg = importMsg.substring(0, j);
+                removed = true;
+            }
+    
+            //if it is something like aaa.sss.bb : removes the bb because it is the qualifier
+            //if it is something like aaa.sss.   : removes only the last point
+            if (!removed && importMsg.length() > 0 && importMsg.indexOf('.') != -1){
+                importMsg = importMsg.substring(0, importMsg.lastIndexOf('.'));
+            }
+            
+            
+            return new ImportInfo(importMsg, foundImportOnArray);
         }
+    }
 
-        //if it is something like aaa.sss.bb : removes the bb because it is the qualifier
-        //if it is something like aaa.sss.   : removes only the last point
-        if (importMsg.length() > 0 && importMsg.indexOf('.') != -1){
-            importMsg = importMsg.substring(0, importMsg.lastIndexOf('.'));
+    private static ImportInfo doExistingOrEmptyReturn(boolean returnEvenEmpty, String importMsg, boolean foundImportOnArray) {
+        if(returnEvenEmpty || importMsg.trim().length() > 0){
+            return new ImportInfo(" ", foundImportOnArray); 
+        }else{
+            return new ImportInfo("", foundImportOnArray); 
         }
-        
-        
-        return importMsg;
     }
 
     /**
@@ -629,11 +743,14 @@ public class PyCodeCompletion {
 
     
     /**
-     * @param pythonAndTemplateProposals
-     * @param qualifier
-     * @return
+     * Filters the python completions so that only the completions we care about are shown (given the qualifier) 
+     * @param pythonAndTemplateProposals the completions to sort / filter
+     * @param qualifier the qualifier we care about
+     * @param onlyForCalltips if we should filter having in mind that we're going to show it for a calltip
+     * @return the completions to show to the user
      */
-    public ICompletionProposal[] onlyValidSorted(List pythonAndTemplateProposals, String qualifier) {
+    @SuppressWarnings("unchecked")
+    public ICompletionProposal[] onlyValidSorted(List pythonAndTemplateProposals, String qualifier, boolean onlyForCalltips) {
         //FOURTH: Now, we have all the proposals, only thing is deciding wich ones are valid (depending on
         //qualifier) and sorting them correctly.
         Collection returnProposals = new HashSet();
@@ -644,8 +761,19 @@ public class PyCodeCompletion {
             if (o instanceof ICompletionProposal) {
                 ICompletionProposal proposal = (ICompletionProposal) o;
             
-	            if (proposal.getDisplayString().toLowerCase().startsWith(lowerCaseQualifier)) {
-	                returnProposals.add(proposal);
+                String displayString = proposal.getDisplayString();
+                if(onlyForCalltips){
+                    if (displayString.equals(qualifier)){
+                        returnProposals.add(proposal);
+                        
+                    }else if (displayString.length() > qualifier.length() && displayString.startsWith(qualifier)){
+                        if(displayString.charAt(qualifier.length()) == '('){
+                            returnProposals.add(proposal);
+                            
+                        }
+                    }
+                }else if (displayString.toLowerCase().startsWith(lowerCaseQualifier)) {
+                    returnProposals.add(proposal);
 	            }
             }else{
                 throw new RuntimeException("Error: expected instanceof ICompletionProposal and received: "+o.getClass().getName());
