@@ -8,13 +8,19 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.ITextViewer;
+import org.eclipse.jface.text.contentassist.ContentAssistEvent;
+import org.eclipse.jface.text.contentassist.ContentAssistant;
+import org.eclipse.jface.text.contentassist.ICompletionListener;
 import org.eclipse.jface.text.contentassist.ICompletionProposal;
 import org.eclipse.jface.text.contentassist.IContentAssistProcessor;
 import org.eclipse.jface.text.contentassist.IContextInformation;
 import org.eclipse.jface.text.contentassist.IContextInformationValidator;
+import org.eclipse.jface.util.IPropertyChangeListener;
+import org.eclipse.jface.util.PropertyChangeEvent;
 import org.python.pydev.core.docutils.PySelection;
 import org.python.pydev.editor.PyEdit;
 import org.python.pydev.editor.codecompletion.revisited.CompletionRecursionException;
@@ -28,6 +34,34 @@ import org.python.pydev.plugin.PydevPlugin;
  */
 public class PythonCompletionProcessor implements IContentAssistProcessor {
 
+    //-------- cycling through regular completions and templates
+    private static final int SHOW_ALL = 1;
+    private static final int SHOW_ONLY_TEMPLATES = 2;
+    private int whatToShow = SHOW_ALL;
+    
+    public void startCycle(){
+        whatToShow = SHOW_ALL;
+    }
+    
+    private void doCycle() {
+        if(whatToShow == SHOW_ALL){
+            whatToShow = SHOW_ONLY_TEMPLATES;
+        }else{
+            whatToShow = SHOW_ALL;
+        }
+    }
+    
+    public void updateStatus(){
+        if(whatToShow == SHOW_ALL){
+            pyContentAssistant.setStatusMessage("Press Ctrl+Space for templates.");
+        }else{
+            pyContentAssistant.setStatusMessage("Press Ctrl+Space for default completions.");
+        }
+    }
+    //-------- end cycling through regular completions and templates
+
+
+    
     /**
      * This makes the templates completion
      */
@@ -48,13 +82,57 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      */
     private Throwable error;
 
-
+    /**
+     * These are the activation chars (cache)
+     */
+    private char[] activationChars = null;
 
     /**
-     * @param edit
+     * This is the class that manages the context information (validates it and
+     * changes its presentation).
      */
-    public PythonCompletionProcessor(PyEdit edit) {
+    private PyContextInformationValidator contextInformationValidator;
+    
+    /**
+     * This is the content assistant that is used to start this processor.
+     */
+    private ContentAssistant pyContentAssistant;
+    
+    /**
+     * @param edit the editor that works with this processor
+     * @param pyContentAssistant the content assistant that will invoke this completion
+     */
+    public PythonCompletionProcessor(PyEdit edit, ContentAssistant pyContentAssistant) {
         this.edit = edit;
+        this.pyContentAssistant = pyContentAssistant;
+        
+        contextInformationValidator = new PyContextInformationValidator();
+        
+        //clears the cache when the preferences are changed.
+        IPreferenceStore preferenceStore = PydevPlugin.getDefault().getPreferenceStore();
+        preferenceStore.addPropertyChangeListener(new IPropertyChangeListener(){
+
+            public void propertyChange(PropertyChangeEvent event) {
+                activationChars = null; //clear the cache when it changes
+            }
+            
+        });
+        
+        pyContentAssistant.addCompletionListener(new ICompletionListener(){
+
+            public void assistSessionEnded(ContentAssistEvent event) {
+            }
+
+            public void assistSessionStarted(ContentAssistEvent event) {
+                startCycle();
+            }
+
+            public void selectionChanged(ICompletionProposal proposal, boolean smartToggle) {
+                //ignore
+            }
+            
+        });
+
     }
 
 
@@ -63,7 +141,9 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      * 
      * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#computeCompletionProposals(org.eclipse.jface.text.ITextViewer, int)
      */
+    @SuppressWarnings("unchecked")
     public ICompletionProposal[] computeCompletionProposals(ITextViewer viewer, int documentOffset) {
+        updateStatus();
         ICompletionProposal[] proposals;
         
         try {
@@ -72,21 +152,26 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
 
 
             //list for storing the proposals
-            ArrayList pythonAndTemplateProposals = new ArrayList();
+            ArrayList<ICompletionProposal> pythonAndTemplateProposals = new ArrayList<ICompletionProposal>();
             
+            CompletionRequest request = new CompletionRequest(edit.getEditorFile(), 
+                    edit.getPythonNature(), doc, documentOffset, codeCompletion);
             
+
             
             //SECOND: getting code completions and deciding if templates should be shown too.
             boolean showTemplates = true;
             //Get code completion proposals
             if(PyCodeCompletionPreferencesPage.useCodeCompletion()){
                 Object[] objects = new Object[]{new ArrayList(), new Boolean(true)};
-                try {
-                    objects = getPythonProposals(viewer, documentOffset, doc);
-                } catch (CompletionRecursionException e) {
-                    //thats ok
-                } catch (Throwable e) {
-                    setError(e);
+                if(whatToShow == SHOW_ALL){
+                    try {
+                        objects = getPythonProposals(viewer, documentOffset, doc, request);
+                    } catch (CompletionRecursionException e) {
+                        //thats ok
+                    } catch (Throwable e) {
+                        setError(e);
+                    }
                 }
 
                 List pythonProposals = (List) objects[0];
@@ -95,9 +180,7 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
             }
             
             
-            
-            
-            String[] strs = PySelection.getActivationTokenAndQual(doc, documentOffset); 
+            String[] strs = PySelection.getActivationTokenAndQual(doc, documentOffset, false); 
 
             String activationToken = strs[0];
             String qualifier = strs[1];
@@ -110,14 +193,16 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
             }
 
             
+            //to show the valid ones, we'll get the qualifier from the initial request
+            proposals = codeCompletion.onlyValidSorted(pythonAndTemplateProposals, request.qualifier, request.isInCalltip);
             
-            proposals = codeCompletion.onlyValidSorted(pythonAndTemplateProposals, qualifier);
-            // Return the proposals
         } catch (RuntimeException e) {
             proposals = new ICompletionProposal[0];
             setError(e);
         }
-        
+    
+        doCycle();
+        // Return the proposals
         return proposals;
     }
 
@@ -126,6 +211,7 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
     
 
 
+
     /**
      * @param e
      */
@@ -143,17 +229,14 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      * @throws CoreException
      * @throws BadLocationException
      */
-    private Object[] getPythonProposals(ITextViewer viewer, int documentOffset, IDocument doc) throws CoreException, BadLocationException {
-        CompletionRequest request = new CompletionRequest(edit.getEditorFile(), 
-                edit.getPythonNature(), doc, documentOffset,
-                codeCompletion);
+    private Object[] getPythonProposals(ITextViewer viewer, int documentOffset, IDocument doc, CompletionRequest request) throws CoreException, BadLocationException {
         boolean showTemplates = true;
         
         //if non empty string, we're in imports section.
-        String importsTipperStr = request.codeCompletion.getImportsTipperStr(request);
+        String importsTipperStr = request.codeCompletion.getImportsTipperStr(request).importsTipperStr;
         
-        if (importsTipperStr.length() != 0){
-            showTemplates = false; //don't show templates if we are in the imports section.
+        if (importsTipperStr.length() != 0 || request.isInCalltip){
+            showTemplates = false; //don't show templates if we are in the imports section or inside a calltip.
         }
         
         List allProposals = request.codeCompletion.getCodeCompletionProposals(viewer, request);
@@ -173,10 +256,19 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
     }
 
     /**
-     * 
+     * Ok, if we have 
      * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#computeContextInformation(org.eclipse.jface.text.ITextViewer, int)
      */
     public IContextInformation[] computeContextInformation(ITextViewer viewer, int documentOffset) {
+    	//System.out.println("computeContextInformation");
+    	if(viewer.getDocument() != this.contextInformationValidator.doc){
+    		return null;
+    	}
+    	//System.out.println("this.contextInformationValidator.returnedFalseOnce:"+this.contextInformationValidator.returnedFalseOnce);
+    	//if we didn't return false at least once, it is already installed.
+    	if(this.contextInformationValidator.returnedFalseOnce && this.contextInformationValidator.isContextInformationValid(documentOffset)){
+    		return new IContextInformation[]{this.contextInformationValidator.fInformation};
+    	}
         return null;
     }
 
@@ -185,6 +277,10 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getCompletionProposalAutoActivationCharacters()
      */
     public char[] getCompletionProposalAutoActivationCharacters() {
+        if(activationChars != null){ //let's cache this
+            return activationChars;
+        }
+        
         char[] c = new char[0];
         if (PyCodeCompletionPreferencesPage.isToAutocompleteOnDot()) {
             c = addChar(c, '.');
@@ -192,6 +288,8 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
         if (PyCodeCompletionPreferencesPage.isToAutocompleteOnPar()) {
             c = addChar(c, '(');
         }
+        activationChars = c;
+ 
         return c;
     }
 
@@ -220,7 +318,7 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getContextInformationAutoActivationCharacters()
      */
     public char[] getContextInformationAutoActivationCharacters() {
-        return new char[] {};
+        return null;
     }
 
     /**
@@ -242,7 +340,8 @@ public class PythonCompletionProcessor implements IContentAssistProcessor {
      * @see org.eclipse.jface.text.contentassist.IContentAssistProcessor#getContextInformationValidator()
      */
     public IContextInformationValidator getContextInformationValidator() {
-        return null;
+        return this.contextInformationValidator;
     }
 
+
 }
\ No newline at end of file
