@@ -4,6 +4,7 @@ import java.io.File;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
@@ -13,11 +14,13 @@ import java.util.SortedMap;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.jface.text.IDocument;
+import org.python.pydev.core.ExtensionHelper;
 import org.python.pydev.core.FindInfo;
 import org.python.pydev.core.FullRepIterable;
 import org.python.pydev.core.ICodeCompletionASTManager;
 import org.python.pydev.core.ICompletionRequest;
 import org.python.pydev.core.ICompletionState;
+import org.python.pydev.core.ILocalScope;
 import org.python.pydev.core.IModule;
 import org.python.pydev.core.IModulesManager;
 import org.python.pydev.core.IPythonNature;
@@ -25,15 +28,22 @@ import org.python.pydev.core.IToken;
 import org.python.pydev.core.ModulesKey;
 import org.python.pydev.core.REF;
 import org.python.pydev.core.Tuple;
+import org.python.pydev.core.Tuple3;
+import org.python.pydev.core.log.Log;
 import org.python.pydev.editor.actions.PyAction;
 import org.python.pydev.editor.codecompletion.CompletionRequest;
+import org.python.pydev.editor.codecompletion.IPyDevCompletionParticipant;
 import org.python.pydev.editor.codecompletion.PyCodeCompletion;
 import org.python.pydev.editor.codecompletion.revisited.modules.AbstractModule;
 import org.python.pydev.editor.codecompletion.revisited.modules.SourceModule;
+import org.python.pydev.editor.codecompletion.revisited.modules.SourceToken;
 import org.python.pydev.editor.codecompletion.revisited.visitors.Definition;
+import org.python.pydev.editor.codecompletion.revisited.visitors.LocalScope;
 import org.python.pydev.parser.PyParser;
 import org.python.pydev.parser.jython.SimpleNode;
 import org.python.pydev.parser.jython.ast.FunctionDef;
+import org.python.pydev.parser.jython.ast.ImportFrom;
+import org.python.pydev.parser.jython.ast.NameTok;
 import org.python.pydev.parser.visitors.NodeUtils;
 
 public abstract class AbstractASTManager implements ICodeCompletionASTManager, Serializable {
@@ -78,44 +88,94 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      * or something like 'foo.bar' or an empty string (if only 'import').
      * @return a Set with the imports as tuples with the name, the docstring.
      */
-    public IToken[] getCompletionsForImport(final String original, ICompletionRequest r) {
+    public IToken[] getCompletionsForImport(ImportInfo importInfo, ICompletionRequest r) {
+        String original = importInfo.importsTipperStr;
+        String afterDots = null;
+        int level = 0; //meaning: no absolute import
+        
+        boolean onlyDots = true;
+        if(original.startsWith(".")){
+            //if the import has leading dots, this means it is something like
+            //from ...bar import xxx (new way to express the relative import)
+            for(int i = 0; i< original.length(); i++){
+                if(original.charAt(i) != '.'){
+                    onlyDots = false;
+                    afterDots = original.substring(i);
+                    break;
+                }
+                //add one to the relative import level
+                level++;
+            }
+        }
         CompletionRequest request = (CompletionRequest) r;
         IPythonNature nature = request.nature;
         
         String relative = null;
+        String moduleName = null;
         if(request.editorFile != null){
-            String moduleName = nature.getAstManager().getModulesManager().resolveModule(REF.getFileAbsolutePath(request.editorFile));
+            moduleName = nature.getAstManager().getModulesManager().resolveModule(REF.getFileAbsolutePath(request.editorFile));
             if(moduleName != null){
-                String tail = FullRepIterable.headAndTail(moduleName)[0];
-                if(original.length() > 0){
-                    relative = tail+"."+original;
+                
+                if(level > 0){
+                    //ok, it is the import added on python 2.5 (from .. import xxx)
+                    String[] moduleParts = FullRepIterable.dotSplit(moduleName);
+                    if(moduleParts.length > level){
+                        relative = FullRepIterable.joinParts(moduleParts, moduleParts.length-level);
+                    }
+                    
+                    if(!onlyDots){
+                        //ok, we have to add the other part too, as we have more than the leading dots
+                        //from ..bar import 
+                        relative += "."+afterDots;
+                    }
+                    
                 }else{
-                    relative = tail;
+                    String tail = FullRepIterable.headAndTail(moduleName)[0];
+                    if(original.length() > 0){
+                        relative = tail+"."+original;
+                    }else{
+                        relative = tail;
+                    }
                 }
             }
         }
         
+        //set to hold the completion (no duplicates allowed).
+        Set<IToken> set = new HashSet<IToken>();
+
         String absoluteModule = original;
         if (absoluteModule.endsWith(".")) {
             absoluteModule = absoluteModule.substring(0, absoluteModule.length() - 1);
         }
-        //absoluteModule = absoluteModule.toLowerCase().trim();
-
-        //set to hold the completion (no duplicates allowed).
-        Set<IToken> set = new HashSet<IToken>();
-
-        //first we get the imports... that complete for the token.
-        getAbsoluteImportTokens(absoluteModule, set, PyCodeCompletion.TYPE_IMPORT, false);
-
-        //Now, if we have an initial module, we have to get the completions
-        //for it.
-        getTokensForModule(original, nature, absoluteModule, set);
+        
+        if(level == 0){
+            //first we get the imports... that complete for the token.
+            getAbsoluteImportTokens(absoluteModule, set, PyCodeCompletion.TYPE_IMPORT, false);
+    
+            //Now, if we have an initial module, we have to get the completions
+            //for it.
+            getTokensForModule(original, nature, absoluteModule, set);
+        }
 
         if(relative != null && relative.equals(absoluteModule) == false){
             getAbsoluteImportTokens(relative, set, PyCodeCompletion.TYPE_RELATIVE_IMPORT, false);
-            getTokensForModule(relative, nature, relative, set);
+            if(importInfo.hasImportSubstring){
+                getTokensForModule(relative, nature, relative, set);
+            }
         }
-        return (IToken[]) set.toArray(new IToken[0]);
+        
+        if(level == 1 && moduleName != null){
+            //has returned itself, so, let's remove it
+            String strToRemove = FullRepIterable.getLastPart(moduleName);
+            for(Iterator<IToken> it=set.iterator();it.hasNext();){
+                IToken o = it.next();
+                if(o.getRepresentation().equals(strToRemove)){
+                    it.remove();
+                    //don't break because the token might be different, but not the representation...
+                }
+            }
+        }
+        return set.toArray(new IToken[0]);
     }
 
     
@@ -194,11 +254,11 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
             
             IToken[] globalTokens;
             if(tok != null && tok.length() > 0){
-                CompletionState state2 = new CompletionState(-1,-1,tok,nature);
+                CompletionState state2 = new CompletionState(-1,-1,tok,nature,"");
                 state2.builtinsGotten = true; //we don't want to get builtins here
                 globalTokens = m.getGlobalTokens(state2, this);
             }else{
-                CompletionState state2 = new CompletionState(-1,-1,"",nature);
+                CompletionState state2 = new CompletionState(-1,-1,"",nature,"");
                 state2.builtinsGotten = true; //we don't want to get builtins here
                 globalTokens = getCompletionsForModule(m, state2);
             }
@@ -232,7 +292,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      */
     public IToken[] getCompletionsForToken(File file, IDocument doc, ICompletionState state) {
         IModule module = createModule(file, doc, state, this);
-        return getCompletionsForModule(module, state);
+        return getCompletionsForModule(module, state, true, true);
     }
 
 	/** 
@@ -245,7 +305,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
 	        SimpleNode n = obj.o1;
 	        IModule module = AbstractModule.createModule(n);
         
-            completionsForModule = getCompletionsForModule(module, state);
+            completionsForModule = getCompletionsForModule(module, state, true, true);
 
         } catch (CompletionRecursionException e) {
             completionsForModule = new IToken[]{ new ConcreteToken(e.getMessage(), e.getMessage(), "","", PyCodeCompletion.TYPE_UNKNOWN)};
@@ -266,7 +326,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
     /**
      * This method returns the module that corresponds to the path passed as a parameter.
      * 
-     * @param name
+     * @param name the name of the module we're looking for
      * @param lookingForRelative determines whether we're looking for a relative module (in which case we should
      * not check in other places... only in the module)
      * @return the module represented by this name
@@ -310,12 +370,26 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      * @see org.python.pydev.editor.codecompletion.revisited.ICodeCompletionASTManage#getCompletionsForModule(org.python.pydev.editor.codecompletion.revisited.modules.AbstractModule, org.python.pydev.editor.codecompletion.revisited.CompletionState, boolean)
      */
     public IToken[] getCompletionsForModule(IModule module, ICompletionState state, boolean searchSameLevelMods) {
+        return getCompletionsForModule(module, state, true, false);
+    }
+    
+    /** 
+     * @see org.python.pydev.editor.codecompletion.revisited.ICodeCompletionASTManage#getCompletionsForModule(org.python.pydev.editor.codecompletion.revisited.modules.AbstractModule, org.python.pydev.editor.codecompletion.revisited.CompletionState, boolean, boolean)
+     */
+    public IToken[] getCompletionsForModule(IModule module, ICompletionState state, boolean searchSameLevelMods, boolean lookForArgumentCompletion) {
+        if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+            Log.toLogFile(this, "getCompletionsForModule");
+        }
         ArrayList<IToken> importedModules = new ArrayList<IToken>();
+        ILocalScope localScope = null;
         if(state.getLocalImportsGotten() == false){
             //in the first analyzed module, we have to get the local imports too. 
             state.setLocalImportsGotten (true);
             if(module != null){
-                importedModules.addAll(module.getLocalImportedModules(state.getLine(), state.getCol()));
+                localScope = module.getLocalScope(state.getLine(), state.getCol());
+                if(localScope != null){
+                    importedModules.addAll(localScope.getLocalImportedModules(state.getLine(), state.getCol(), module.getName()));
+                }
             }
         }
 
@@ -323,6 +397,14 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
         if(builtinsCompletions != null){
             return builtinsCompletions;
         }
+        
+        String act = state.getActivationToken();
+        int parI = act.indexOf('(');
+        if(parI != -1){
+            act = act.substring(0, parI);
+            state.setActivationToken(act);
+            state.setLookingForInstance(true);
+        }
         	
         if (module != null) {
 
@@ -366,16 +448,16 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
             }else{ //ok, we have a token, find it and get its completions.
                 
                 //first check if the token is a module... if it is, get the completions for that module.
-                IToken[] t = findTokensOnImportedMods(importedModules.toArray(new IToken[0]), state, module);
-                if(t != null && t.length > 0){
-                    return t;
+                IToken[] tokens = findTokensOnImportedMods(importedModules.toArray(new IToken[0]), state, module);
+                if(tokens != null && tokens.length > 0){
+                    return tokens;
                 }
                 
                 //if it is an __init__, modules on the same level are treated as local tokens
                 if(searchSameLevelMods){
-	                t = searchOnSameLevelMods(initial, state);
-	                if(t != null && t.length > 0){
-	                	return t;
+	                tokens = searchOnSameLevelMods(initial, state);
+	                if(tokens != null && tokens.length > 0){
+	                	return tokens;
 	                }
                 }
 
@@ -400,7 +482,6 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
                 }
 
                 //it was not a module (would have returned already), so, try to get the completions for a global token defined.
-                IToken[] tokens = null;
                 tokens = module.getGlobalTokens(state, this);
                 if (tokens.length > 0){
                     return tokens;
@@ -416,6 +497,13 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
 	                    }
 	                }
                 }
+
+                if(lookForArgumentCompletion){
+                    tokens = getArgsCompletion(state, localScope);
+                    if(tokens != null && tokens.length > 0){
+                        return tokens;
+                    }
+                }
                 
                 return getAssignCompletions( module, state);
             }
@@ -428,6 +516,51 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
         return new IToken[0];
     }
 
+
+
+
+    /**
+     * Get the completions based on the arguments received
+     * 
+     * @param state this is the state used for the completion
+     * @param localScope this is the scope we're currently on (may be null)
+     */
+    @SuppressWarnings("unchecked")
+    private IToken[] getArgsCompletion(ICompletionState state, ILocalScope localScope) {
+        if (localScope != null){
+            LocalScope s = (LocalScope) localScope;
+            IToken[] args = localScope.getLocalTokens(-1,-1,true); //only to get the args
+            String activationToken = state.getActivationToken();
+            String firstPart = FullRepIterable.getFirstPart(activationToken);
+            for (IToken token : args) {
+                if(token.getRepresentation().equals(firstPart)){
+                    IToken[] interfaceForLocal = s.getInterfaceForLocal(firstPart, state.getActivationToken());
+                    Collection argsCompletionFromParticipants = getArgsCompletionFromParticipants(state, localScope, interfaceForLocal);
+                    for (IToken t : interfaceForLocal) {
+                        if(!t.getRepresentation().equals(state.getQualifier())){
+                            argsCompletionFromParticipants.add(t);
+                        }
+                    }
+                    return (IToken[]) argsCompletionFromParticipants.toArray(new IToken[0]);
+                }
+            }
+        }
+        return null;
+    }
+    
+    @SuppressWarnings("unchecked")
+    private Collection getArgsCompletionFromParticipants(ICompletionState state, ILocalScope localScope, IToken[] interfaceForLocal) {
+        ArrayList ret = new ArrayList();
+        
+        List participants = ExtensionHelper.getParticipants(ExtensionHelper.PYDEV_COMPLETION);
+        for (Iterator iter = participants.iterator(); iter.hasNext();) {
+            IPyDevCompletionParticipant participant = (IPyDevCompletionParticipant) iter.next();
+            ret.addAll(participant.getArgsCompletion(state, localScope, interfaceForLocal));
+        }
+        return ret;
+    }
+
+
     /**
      * Attempt to search on modules on the same level as this one (this will only happen if we are in an __init__
      * module (otherwise, the initial set will be empty)
@@ -493,7 +626,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
         if (module instanceof SourceModule) {
             SourceModule s = (SourceModule) module;
             try {
-                Definition[] defs = s.findDefinition(state.getActivationToken(), state.getLine(), state.getCol(), state.getNature(), new ArrayList<FindInfo>());
+                Definition[] defs = s.findDefinition(state, state.getLine(), state.getCol(), state.getNature(), new ArrayList<FindInfo>());
                 for (int i = 0; i < defs.length; i++) {
                     if(!(defs[i].ast instanceof FunctionDef)){
                         //we might want to extend that later to check the return of some function...
@@ -524,10 +657,13 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
         return new IToken[0];
     }
 
-    /** 
-     * @see org.python.pydev.editor.codecompletion.revisited.ICodeCompletionASTManage#getGlobalCompletions
+    /**
+     * @see ICodeCompletionASTManager#getGlobalCompletions
      */
-    public List getGlobalCompletions(IToken[] globalTokens, IToken[] importedModules, IToken[] wildImportedModules, ICompletionState state, IModule current) {
+    public List<IToken> getGlobalCompletions(IToken[] globalTokens, IToken[] importedModules, IToken[] wildImportedModules, ICompletionState state, IModule current) {
+        if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+            Log.toLogFile(this, "getGlobalCompletions");
+        }
         List<IToken> completions = new ArrayList<IToken>();
 
         //in completion with nothing, just go for what is imported and global tokens.
@@ -549,8 +685,14 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
 
         if(!state.getBuiltinsGotten()){
             state.setBuiltinsGotten (true) ;
+            if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+                Log.toLogFile(this, "getBuiltinCompletions");
+            }
             //last thing: get completions from module __builtin__
             getBuiltinCompletions(state, completions);
+            if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+                Log.toLogFile(this, "END getBuiltinCompletions");
+            }
         }
         return completions;
     }
@@ -600,8 +742,88 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
 	}
 
     /**
-     * @see org.python.pydev.editor.codecompletion.revisited.ICodeCompletionASTManage#getCompletionsForWildImport
+     * Resolves a token defined with 'from module import something' statement 
+     * to a proper type, as defined in module.  
+     * @param imported the token to resolve.
+     * @return the resolved token or the original token in case no additional information could be obtained.
      */
+    public IToken resolveImport(ICompletionState state, IToken imported) {
+        String curModName = imported.getParentPackage();
+        Tuple3<IModule, String, IToken> modTok = findOnImportedMods(new IToken[]{imported}, state.getNature(), imported.getRepresentation(), curModName);
+        if(modTok != null && modTok.o1 != null){
+
+            if(modTok.o2.length() == 0){
+                return imported; //it's a module actually, so, no problems...
+                
+            } else{
+                try{
+                    state.checkResolveImportMemory(modTok.o1, modTok.o2);
+                }catch(CompletionRecursionException e){
+                    return imported;
+                }
+                IToken repInModule = getRepInModule(modTok.o1, modTok.o2, state.getNature(), state);
+                if(repInModule != null){
+                    return repInModule;
+                }
+            }
+        }
+        return imported;
+            
+    }
+
+    /**
+     * This is the public interface
+     * @see org.python.pydev.core.ICodeCompletionASTManager#getRepInModule(org.python.pydev.core.IModule, java.lang.String, org.python.pydev.core.IPythonNature)
+     */
+    public IToken getRepInModule(IModule module, String tokName, IPythonNature nature) {
+        return getRepInModule(module, tokName, nature, null);
+    }
+    
+    /**
+     * Get the actual token representing the tokName in the passed module  
+     * @param module the module where we're looking
+     * @param tokName the name of the token we're looking for
+     * @param nature the nature we're looking for
+     * @return the actual token in the module (or null if it was not possible to find it).
+     */
+    private IToken getRepInModule(IModule module, String tokName, IPythonNature nature, ICompletionState state) {
+        if(module != null){
+            if(tokName.startsWith(".")){
+                tokName = tokName.substring(1);
+            }
+
+            //ok, we are getting some token from the module... let's see if it is really available.
+            String[] headAndTail = FullRepIterable.headAndTail(tokName);
+            String actToken = headAndTail[0];  //tail (if os.path, it is os) 
+            String hasToBeFound = headAndTail[1]; //head (it is path)
+            
+            //if it was os.path:
+            //initial would be os.path
+            //foundAs would be os
+            //actToken would be path
+            
+            //now, what we will do is try to do a code completion in os and see if path is found
+            if(state == null){
+                state = CompletionState.getEmptyCompletionState(actToken, nature);
+            }else{
+                state = state.getCopy();
+                state.setActivationToken(actToken);
+            }
+            IToken[] completionsForModule = getCompletionsForModule(module, state);
+            for (IToken foundTok : completionsForModule) {
+                if(foundTok.getRepresentation().equals(hasToBeFound)){
+                    return foundTok;
+                }
+            }
+        }
+        return null;
+    }
+
+
+    /* (non-Javadoc)
+     * @see ICodeCompletionASTManager#getCompletionsForWildImport(ICompletionState, IModule, List, IToken)
+     */
+    @SuppressWarnings("unchecked")
     public List getCompletionsForWildImport(ICompletionState state, IModule current, List completions, IToken name) {
         try {
         	//this one is an exception... even though we are getting the name as a relative import, we say it
@@ -633,7 +855,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
     }
 
     public IToken[] findTokensOnImportedMods( IToken[] importedModules, ICompletionState state, IModule current) {
-        Tuple<IModule, String> o = findOnImportedMods(importedModules, state.getNature(), state.getActivationToken(), current.getName());
+        Tuple3<IModule, String, IToken> o = findOnImportedMods(importedModules, state.getNature(), state.getActivationToken(), current.getName());
         
         if(o == null)
             return null;
@@ -667,7 +889,7 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      * 0: mod
      * 1: tok
      */
-    public Tuple<IModule, String> findOnImportedMods( IPythonNature nature, String activationToken, IModule current) {
+    public Tuple3<IModule, String, IToken> findOnImportedMods( IPythonNature nature, String activationToken, IModule current) {
         IToken[] importedModules = current.getTokenImportedModules();
         return findOnImportedMods(importedModules, nature, activationToken, current.getName());
     }
@@ -685,9 +907,10 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      * the TestCase is put as the module
      * 
      * 0: mod
-     * 1: tok
+     * 1: tok (string)
+     * 2: actual tok
      */
-    public Tuple<IModule, String> findOnImportedMods( IToken[] importedModules, IPythonNature nature, String activationToken, String currentModuleName) {
+    public Tuple3<IModule, String, IToken> findOnImportedMods( IToken[] importedModules, IPythonNature nature, String activationToken, String currentModuleName) {
         	
     	FullRepIterable iterable = new FullRepIterable(activationToken, true);
     	for(String tok : iterable){
@@ -697,7 +920,11 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
 	            
 	            if(modRep.equals(tok)){
                     String act = activationToken;
-	            	return findOnImportedMods(importedModule, tok, nature, act, currentModuleName);
+	            	Tuple<IModule, String> r = findOnImportedMods(importedModule, tok, nature, act, currentModuleName);
+                    if(r == null){
+                        return null;
+                    }
+                    return new Tuple3<IModule, String, IToken>(r.o1, r.o2, importedModule);
 	            }
 	        }
         }   
@@ -711,9 +938,50 @@ public abstract class AbstractASTManager implements ICodeCompletionASTManager, S
      */
     protected Tuple<IModule, String> findOnImportedMods(IToken importedModule, String tok, IPythonNature nature, 
     		String activationToken, String currentModuleName) {
-    	
-    	Tuple<IModule, String> modTok = null;
-    	IModule mod = null;
+        
+        
+        Tuple<IModule, String> modTok = null;
+        IModule mod = null;
+
+        //ok, check if it is a token for the new import
+    	if(importedModule instanceof SourceToken){
+    	    SourceToken token = (SourceToken) importedModule;
+            
+            if(token.isImportFrom()){
+                ImportFrom importFrom = (ImportFrom) token.getAst();
+                int level = importFrom.level;
+                if(level > 0){
+                    //ok, it must be treated as a relative import
+                    //ok, it is the import added on python 2.5 (from .. import xxx)
+                    
+                    String parentPackage = token.getParentPackage();
+                    String[] moduleParts = FullRepIterable.dotSplit(parentPackage);
+                    String relative = null;
+                    if(moduleParts.length > level){
+                        relative = FullRepIterable.joinParts(moduleParts, moduleParts.length-level);
+                    }
+                    
+                    String modName = ((NameTok)importFrom.module).id;
+                    if(modName.length() > 0){
+                        //ok, we have to add the other part too, as we have more than the leading dots
+                        //from ..bar import 
+                        relative += "."+modName;
+                    }
+                    relative += "."+tok;
+                    
+                    modTok = findModuleFromPath(relative, nature, false, null);
+                    mod = modTok.o1;
+                    if(checkValidity(currentModuleName, mod)){
+                        Tuple<IModule, String> ret = fixTok(modTok, tok, activationToken);
+                        return ret;
+                    }
+                    //ok, it is 'forced' as relative import because it has a level, so, it MUST return here
+                    return null;
+                }
+            }
+        }
+        
+        
         
         //check as relative with complete rep
         String asRelativeImport = importedModule.getAsRelativeImport(currentModuleName);
