@@ -22,15 +22,21 @@ public class CompletionState implements ICompletionState {
     public int line;
     public int col;
     public IPythonNature nature;
+    public String qualifier;
     
     public Memo<String> memory = new Memo<String>();
     public Memo<Definition> definitionMemory = new Memo<Definition>();
     public Memo<IModule> wildImportMemory = new Memo<IModule>();
     public Memo<String> importedModsCalled = new Memo<String>();
     public Memo<String> findMemory = new Memo<String>();
+    public Memo<String> resolveImportMemory = new Memo<String>();
+    public Memo<String> findDefinitionMemory = new Memo<String>();
     
     public boolean builtinsGotten=false;
     public boolean localImportsGotten=false;
+    public boolean isInCalltip=false;
+    
+    public int lookingForInstance=LOOKING_FOR_INSTANCE_UNDEFINED;
 
     public CompletionState getCopy(){
         CompletionState state = new CompletionState();
@@ -39,14 +45,18 @@ public class CompletionState implements ICompletionState {
         state.col = col;
         state.importedModsCalled = importedModsCalled;
         state.nature = nature;
+        state.qualifier = qualifier;
         
         state.memory = memory;
         state.wildImportMemory = wildImportMemory;
         state.definitionMemory = definitionMemory;
         state.findMemory = findMemory;
-
+        state.resolveImportMemory = resolveImportMemory;
+        state.findDefinitionMemory = findDefinitionMemory;
+        
         state.builtinsGotten = builtinsGotten;
         state.localImportsGotten = localImportsGotten;
+        state.isInCalltip = isInCalltip;
         
         return state;
     }
@@ -117,11 +127,12 @@ public class CompletionState implements ICompletionState {
      * @param qual
      * @param nature2
      */
-    public CompletionState(int line2, int col2, String token, IPythonNature nature2) {
+    public CompletionState(int line2, int col2, String token, IPythonNature nature2, String qualifier) {
         this.line = line2;
         this.col = col2;
         this.activationToken = token;
         this.nature = nature2;
+        this.qualifier = qualifier;
     }
     
     public CompletionState(){
@@ -160,6 +171,23 @@ public class CompletionState implements ICompletionState {
         }
         
     }
+    
+    /**
+     * @param module
+     */
+    public void checkResolveImportMemory(IModule module, String value) {
+        if(this.resolveImportMemory.isInRecursion(module, value)){
+            throw new CompletionRecursionException("Possible recursion found (value: "+value+") - stopping analysis.");
+        }
+        
+    }
+
+	public void checkFindDefinitionMemory(IModule mod, String tok) {
+		if(this.findDefinitionMemory.isInRecursion(mod, tok)){
+			throw new CompletionRecursionException("Possible recursion found (value: "+tok+") - stopping analysis.");
+		}
+	}
+	
     /**
      * @param module
      * @param base
@@ -174,14 +202,14 @@ public class CompletionState implements ICompletionState {
      * @return a default completion state for globals (empty act. token)
      */
     public static ICompletionState getEmptyCompletionState(IPythonNature nature) {
-        return new CompletionState(0,0,"", nature);
+        return new CompletionState(0,0,"", nature,"");
     }
     
     /**
      * @return a default completion state for globals (act token defined)
      */
     public static ICompletionState getEmptyCompletionState(String token, IPythonNature nature) {
-        return new CompletionState(0,0,token, nature);
+        return new CompletionState(0,0,token, nature,"");
     }
 
     public String getActivationToken() {
@@ -233,5 +261,36 @@ public class CompletionState implements ICompletionState {
 			throw new CompletionRecursionException("Possible recursion found (mod: "+mod.getName()+", tok: "+ tok +" ) - stopping analysis.");
 		}
 	}
+
+    public boolean getIsInCalltip() {
+        return isInCalltip;
+    }
+
+    public void setLookingForInstance(boolean b) {
+        if(this.lookingForInstance == LOOKING_FOR_INSTANCE_UNDEFINED){
+            if(b){
+                this.lookingForInstance = LOOKING_FOR_INSTANCED_VARIABLE;
+            }else{
+                this.lookingForInstance = LOOKING_FOR_UNBOUND_VARIABLE;
+            }
+        }
+    }
+
+    public boolean getIsLookingForInstance() {
+        if(this.lookingForInstance == LOOKING_FOR_INSTANCE_UNDEFINED || this.lookingForInstance == LOOKING_FOR_INSTANCED_VARIABLE){
+            return true; 
+        }
+        return false;
+    }
+
+    public ICompletionState getCopyWithActTok(String value) {
+        CompletionState copy = getCopy();
+        copy.setActivationToken(value);
+        return copy;
+    }
+
+    public String getQualifier() {
+        return this.qualifier;
+    }
     
 }
