@@ -28,6 +28,7 @@ import org.eclipse.jface.text.IDocument;
 import org.python.pydev.core.IModule;
 import org.python.pydev.core.IModulesManager;
 import org.python.pydev.core.IPythonNature;
+import org.python.pydev.core.IToken;
 import org.python.pydev.core.ModulesKey;
 import org.python.pydev.core.REF;
 import org.python.pydev.core.Tuple;
@@ -151,6 +152,7 @@ public abstract class ModulesManager implements IModulesManager, Serializable {
         }
     }
 
+    
     /**
      * Custom serialization is needed.
      */
@@ -452,7 +454,7 @@ public abstract class ModulesManager implements IModulesManager, Serializable {
     /**
      * This method returns the module that corresponds to the path passed as a parameter.
      * 
-     * @param name
+     * @param name the name of the module we're looking for
      * @param dontSearchInit is used in a negative form because initially it was isLookingForRelative, but
      * it actually defines if we should look in __init__ modules too, so, the name matches the old signature.
      * 
@@ -504,7 +506,15 @@ public abstract class ModulesManager implements IModulesManager, Serializable {
             }
         }
         if(foundStartingWithBuiltin){
-        	return null;
+            //ok, just add it if it is some module that actually exists
+            n = new CompiledModule(name, PyCodeCompletion.TYPE_BUILTIN, nature.getAstManager());
+            IToken[] globalTokens = n.getGlobalTokens();
+            if(globalTokens.length > 0 && contains(globalTokens, "__file__")){
+                doAddSingleModule(new ModulesKey(name, null), n);
+                return n;
+            }else{
+                return null;
+            }
         }
 
 
@@ -567,8 +577,28 @@ public abstract class ModulesManager implements IModulesManager, Serializable {
         return n;
 
     }
+    
+    /**
+     * Passes through all the compiled modules in memory and clears its tokens (so that
+     * we restore them when needed).
+     */
+    public void clearCache(){
+        ModulesManager.cache.internalCache.clear();
+    }
 
 
+    /**
+     * @return true if there is a token that has rep as its representation.
+     */
+    private boolean contains(IToken[] tokens, String rep) {
+        for (IToken token : tokens) {
+            if(token.getRepresentation().equals(rep)){
+                return true;
+            }
+        }
+        return false;
+    }
+
     /** 
      * @see org.python.pydev.core.IProjectModulesManager#isInPythonPath(org.eclipse.core.resources.IResource, org.eclipse.core.resources.IProject)
      */
