@@ -7,7 +7,6 @@ package org.python.pydev.editor.codecompletion.revisited.modules;
 
 import java.io.File;
 import java.io.FileNotFoundException;
-import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.jface.text.IDocument;
@@ -15,6 +14,7 @@ import org.python.pydev.core.FindInfo;
 import org.python.pydev.core.FullRepIterable;
 import org.python.pydev.core.ICodeCompletionASTManager;
 import org.python.pydev.core.ICompletionState;
+import org.python.pydev.core.ILocalScope;
 import org.python.pydev.core.IModule;
 import org.python.pydev.core.IModulesManager;
 import org.python.pydev.core.IPythonNature;
@@ -93,9 +93,17 @@ public abstract class AbstractModule implements IModule {
      * @see org.python.pydev.core.IModule#isInGlobalTokens(java.lang.String, org.python.pydev.plugin.nature.PythonNature, boolean)
      */
     public boolean isInGlobalTokens(String tok, IPythonNature nature, boolean searchSameLevelMods){
-    	if(isInDirectGlobalTokens(tok, nature)){
-    		return true;
-    	}
+        return isInGlobalTokens(tok, nature, true, false);
+    }
+    
+    public boolean isInGlobalTokens(String tok, IPythonNature nature, boolean searchSameLevelMods, boolean ifHasGetAttributeConsiderInTokens){
+        //it's just worth checking it if it is not dotted...
+        if(tok.indexOf(".") == -1){
+        	if(isInDirectGlobalTokens(tok, nature)){
+        		return true;
+        	}
+        }
+        
     	//if still not found, we have to get all the tokens, including regular and wild imports
         ICompletionState state = CompletionState.getEmptyCompletionState(nature);
         ICodeCompletionASTManager astManager = nature.getAstManager();
@@ -104,7 +112,17 @@ public abstract class AbstractModule implements IModule {
         String head = headAndTail[1];
         IToken[] globalTokens = astManager.getCompletionsForModule(this, state, searchSameLevelMods);
         for (IToken token : globalTokens) {
-            if(token.getRepresentation().equals(head)){
+            String rep = token.getRepresentation();
+            
+            if(ifHasGetAttributeConsiderInTokens && 
+                    //getattribute
+                    (rep.equals("__getattribute__") || rep.equals("__getattr__")) && 
+                    //but not defined in the builtins (it must be overriden)
+                   token.getParentPackage().startsWith("__builtin__") == false){
+                return true;
+            }
+            
+            if(rep.equals(head)){
                 return true;
             }
         }
@@ -112,10 +130,11 @@ public abstract class AbstractModule implements IModule {
         return false;
     }
     
-    /** 
-     * @see org.python.pydev.core.IModule#findDefinition(java.lang.String, int, int, org.python.pydev.plugin.nature.IPythonNature, java.util.List)
+    
+    /**
+     * The token we're looking for must be the state activation token
      */
-    public abstract Definition[] findDefinition(String token, int line, int col, IPythonNature nature, List<FindInfo> findInfo) throws Exception;
+    public abstract Definition[] findDefinition(ICompletionState state, int line, int col, IPythonNature nature, List<FindInfo> findInfo) throws Exception;
 
     /** 
      * @see org.python.pydev.core.IModule#getGlobalTokens(org.python.pydev.editor.codecompletion.revisited.CompletionState, org.python.pydev.core.ICodeCompletionASTManager)
@@ -255,11 +274,8 @@ public abstract class AbstractModule implements IModule {
         return new EmptyModule(m, f);
     }
 
-    /** 
-     * @see org.python.pydev.core.IModule#getLocalImportedModules(int, int)
-     */
-    public List <IToken> getLocalImportedModules(int line, int col) {
-        return new ArrayList<IToken>();
+    public ILocalScope getLocalScope(int line, int col) {
+        return null;
     }
 
     /** 
