@@ -15,6 +15,7 @@ import java.util.List;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.jface.text.Document;
+import org.python.pydev.core.ExtensionHelper;
 import org.python.pydev.core.FindInfo;
 import org.python.pydev.core.FullRepIterable;
 import org.python.pydev.core.ICodeCompletionASTManager;
@@ -65,6 +66,7 @@ public class CompiledModule extends AbstractModule{
      * 
      * @param module - module from where to get completions.
      */
+    @SuppressWarnings("unchecked")
     public CompiledModule(String name, int tokenTypes, ICodeCompletionASTManager manager){
         super(name);
         if(COMPILED_MODULES_ENABLED){
@@ -92,6 +94,12 @@ public class CompiledModule extends AbstractModule{
 					PydevPlugin.log(e2);
 				}
 	        }
+            if(tokens != null && tokens.length > 0){
+                List<IModulesObserver> participants = ExtensionHelper.getParticipants(ExtensionHelper.PYDEV_MODULES_OBSERVER);
+                for (IModulesObserver observer : participants) {
+                    observer.notifyCompiledModuleCreated(this, manager);
+                }
+            }
         }else{
             //not used if not enabled.
             tokens = new CompiledToken[0];
@@ -261,7 +269,8 @@ public class CompiledModule extends AbstractModule{
      * @param findInfo 
      * @see org.python.pydev.editor.codecompletion.revisited.modules.AbstractModule#findDefinition(java.lang.String, int, int)
      */
-    public Definition[] findDefinition(String token, int line, int col, IPythonNature nature, List<FindInfo> findInfo) throws Exception {
+    public Definition[] findDefinition(ICompletionState state, int line, int col, IPythonNature nature, List<FindInfo> findInfo) throws Exception {
+        String token = state.getActivationToken();
         AbstractShell shell = AbstractShell.getServerShell(nature, AbstractShell.COMPLETION_SHELL);
         synchronized(shell){
             Tuple<String[],int[]> def = shell.getLineCol(this.name, token, nature.getAstManager().getModulesManager().getCompletePythonPath());
@@ -281,7 +290,7 @@ public class CompiledModule extends AbstractModule{
             if(foundLine == 0 && foundAs.length() > 0 && mod != null){
                 IModule sourceMod = AbstractModule.createModuleFromDoc(mod.getName(), f, new Document(REF.getFileContents(f)), nature, 0);
                 if(sourceMod instanceof SourceModule){
-                    Definition[] definitions = (Definition[]) sourceMod.findDefinition(foundAs, 0, 0, nature, findInfo);
+                    Definition[] definitions = (Definition[]) sourceMod.findDefinition(state.getCopyWithActTok(foundAs), 0, 0, nature, findInfo);
                     if(definitions.length > 0){
                         return definitions;
                     }
