@@ -16,11 +16,13 @@ import org.python.pydev.core.FullRepIterable;
 import org.python.pydev.core.ICodeCompletionASTManager;
 import org.python.pydev.core.ICompletionState;
 import org.python.pydev.core.IDefinition;
+import org.python.pydev.core.ILocalScope;
 import org.python.pydev.core.IModule;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.IToken;
 import org.python.pydev.core.REF;
 import org.python.pydev.core.Tuple;
+import org.python.pydev.core.Tuple3;
 import org.python.pydev.core.structure.FastStack;
 import org.python.pydev.editor.codecompletion.revisited.AbstractToken;
 import org.python.pydev.editor.codecompletion.revisited.CompletionRecursionException;
@@ -30,7 +32,7 @@ import org.python.pydev.editor.codecompletion.revisited.visitors.Definition;
 import org.python.pydev.editor.codecompletion.revisited.visitors.FindDefinitionModelVisitor;
 import org.python.pydev.editor.codecompletion.revisited.visitors.FindScopeVisitor;
 import org.python.pydev.editor.codecompletion.revisited.visitors.GlobalModelVisitor;
-import org.python.pydev.editor.codecompletion.revisited.visitors.Scope;
+import org.python.pydev.editor.codecompletion.revisited.visitors.LocalScope;
 import org.python.pydev.parser.jython.SimpleNode;
 import org.python.pydev.parser.jython.ast.Assign;
 import org.python.pydev.parser.jython.ast.Attribute;
@@ -86,9 +88,13 @@ public class SourceModule extends AbstractModule {
     }
 
     /**
-     * @return a reference to all the modules that are imported from this one in the global context in the following constructions:
-     * 
-     * from xxx import xxx import xxx import xxx as ... from xxx import xxx as ....
+     * Searches for the following import tokens:
+     *   import xxx 
+     *   import xxx as ... 
+     *   from xxx import xxx
+     *   from xxx import xxx as ....
+     * Note, that imports with wildcards are not collected.
+     * @return an array of references to the modules that are imported from this one in the global context.
      */
     public IToken[] getTokenImportedModules() {
         return getTokens(GlobalModelVisitor.ALIAS_MODULES);
@@ -174,7 +180,7 @@ public class SourceModule extends AbstractModule {
                     int iActTok = 0;
                     String[] actToks = FullRepIterable.dotSplit(activationToken);
                     if(actToks[iActTok].equals(rep)){
-                        //System.out.println("Now we have to find act..."+act+"(which is a definition of:"+rep+")");
+                        //System.out.println("Now we have to find act..."+activationToken+"(which is a definition of:"+rep+")");
                         try {
                             Definition[] definitions;
                             String value = activationToken;
@@ -187,13 +193,13 @@ public class SourceModule extends AbstractModule {
                                 if(iActTok > actToks.length){
                                     break; //unable to find it
                                 }
-                                definitions = findDefinition(value, token.getLineDefinition(), token.getColDefinition(), manager.getNature(), new ArrayList<FindInfo>());
+                                definitions = findDefinition(initialState.getCopyWithActTok(value), token.getLineDefinition(), token.getColDefinition(), manager.getNature(), new ArrayList<FindInfo>());
                                 if(definitions.length == 1){
                                     Definition d = definitions[0];
                                     if(d.ast instanceof Assign){
                                         Assign assign = (Assign) d.ast;
                                         value = NodeUtils.getRepresentationString(assign.value);
-                                        definitions = findDefinition(value, d.line, d.col, manager.getNature(), new ArrayList<FindInfo>());
+                                        definitions = findDefinition(initialState.getCopyWithActTok(value), d.line, d.col, manager.getNature(), new ArrayList<FindInfo>());
                                     }else if(d.ast instanceof ClassDef){
                                         IToken[] toks = (IToken[]) getToks(initialState, manager, d.ast).toArray(new IToken[0]);
                                         if(iActTok == actToks.length-1){
@@ -202,7 +208,7 @@ public class SourceModule extends AbstractModule {
                                         value = d.value;
                                         
                                     }else if (d.ast instanceof Name){
-                                        ClassDef classDef = d.scope.getClassDef();
+                                        ClassDef classDef = ((LocalScope)d.scope).getClassDef();
                                         if(classDef != null){
                                         	FindDefinitionModelVisitor visitor = new FindDefinitionModelVisitor(actToks[actToks.length-1], d.line, d.col, d.module);
 	                                        classDef.accept(visitor);
@@ -212,32 +218,32 @@ public class SourceModule extends AbstractModule {
 	                                        d = visitor.definitions.get(0);
 	                                        value = d.value;
 	                                        if(d instanceof AssignDefinition){
-	                                            return getValueCompletions(initialState, manager, value);
+	                                            return getValueCompletions(initialState, manager, value, d.module);
 	                                        }
                                         }else{
                                         	if(d.module instanceof SourceModule){
-                                        		FullRepIterable.joinFirstParts(actToks);
                                         		SourceModule m = (SourceModule) d.module;
-                                        		Definition[] definitions2 = m.findDefinition(FullRepIterable.joinFirstParts(actToks), d.line, d.col,manager.getNature(), null);
+                                        		String joined = FullRepIterable.joinFirstParts(actToks);
+                                                Definition[] definitions2 = m.findDefinition(initialState.getCopyWithActTok(joined), d.line, d.col,manager.getNature(), null);
                                         		if(definitions2.length == 0){
                                         			return new IToken[0];
                                         		}
                                         		d = definitions2[0];
                                         		value = d.value+"."+actToks[actToks.length-1];
                                         		if(d instanceof AssignDefinition){
-                                        			return ((SourceModule)d.module).getValueCompletions(initialState, manager, value);
+                                        			return ((SourceModule)d.module).getValueCompletions(initialState, manager, value, d.module);
                                         		}
                                         	}
                                         }
                                         
                                     }else if ((d.ast == null && d.module != null) || d.ast instanceof ImportFrom){
-                                        return getValueCompletions(initialState, manager, value);
+                                        return getValueCompletions(initialState, manager, value, d.module);
                                         
                                     }else{
                                         break;
                                     }
                                 }else{
-                                    return getValueCompletions(initialState, manager, value);
+                                    return getValueCompletions(initialState, manager, value, this);
                                 }
                                 iActTok++;
                             }
@@ -247,6 +253,9 @@ public class SourceModule extends AbstractModule {
                         }
                     }
                 } else if(rep.equals(activationToken)){
+                    if(ast instanceof ClassDef){
+                        initialState.setLookingForInstance(false);
+                    }
                     return (IToken[]) getToks(initialState, manager, ast).toArray(new IToken[0]);
 	            }
 	        }
@@ -262,11 +271,11 @@ public class SourceModule extends AbstractModule {
      * @param value
      * @return
      */
-    private IToken[] getValueCompletions(ICompletionState initialState, ICodeCompletionASTManager manager, String value) {
+    private IToken[] getValueCompletions(ICompletionState initialState, ICodeCompletionASTManager manager, String value, IModule module) {
         initialState.checkFindMemory(this, value);
         ICompletionState copy = initialState.getCopy();
         copy.setActivationToken(value);
-        IToken[] completionsForModule = manager.getCompletionsForModule(this, copy);
+        IToken[] completionsForModule = manager.getCompletionsForModule(module, copy);
         return completionsForModule;
     }
 
@@ -327,7 +336,8 @@ public class SourceModule extends AbstractModule {
     }
 
     @SuppressWarnings("unchecked")
-	public Definition[] findDefinition(String rep, int line, int col, IPythonNature nature, List<FindInfo> lFindInfo) throws Exception{
+	public Definition[] findDefinition(ICompletionState state, int line, int col, IPythonNature nature, List<FindInfo> lFindInfo) throws Exception{
+        String rep = state.getActivationToken();
     	if(lFindInfo == null){
     		lFindInfo = new ArrayList<FindInfo>();
     	}
@@ -384,9 +394,12 @@ public class SourceModule extends AbstractModule {
         List<IToken> localImportedModules = scopeVisitor.scope.getLocalImportedModules(line, col, this.name);
         for (IToken tok : localImportedModules) {
         	if(tok.getRepresentation().equals(rep)){
-        		Tuple<IModule, String> o = nature.getAstManager().findOnImportedMods(new IToken[]{tok}, nature, rep, this.getName());
+                Tuple3<IModule, String, IToken> o = nature.getAstManager().findOnImportedMods(new IToken[]{tok}, nature, rep, this.getName());
                 if(o != null && o.o1 instanceof SourceModule){
-                    findDefinitionsFromModAndTok(nature, toRet, null, (SourceModule) o.o1, o.o2);
+                    ICompletionState copy = state.getCopy();
+                    copy.setActivationToken(o.o2);
+                    
+                    findDefinitionsFromModAndTok(nature, toRet, null, (SourceModule) o.o1, copy);
                 }
                 if(toRet.size() > 0){
                 	return (Definition[]) toRet.toArray(new Definition[0]);
@@ -404,7 +417,7 @@ public class SourceModule extends AbstractModule {
         		//ok, we are in a class, so, let's get the self completions
         		String classRep = NodeUtils.getRepresentationString(classDef);
 				IToken[] globalTokens = getGlobalTokens(
-        				new CompletionState(line, col, classRep, nature), 
+        				new CompletionState(line, col, classRep, nature,""), 
         				nature.getAstManager());
 				
         		String withoutSelf = rep.substring(5);
@@ -422,7 +435,7 @@ public class SourceModule extends AbstractModule {
 							Tuple<Integer, Integer> def = getLineColForDefinition(ast2);
 							FastStack<SimpleNode> stack = new FastStack<SimpleNode>();
 							stack.add(classDef);
-							Scope scope = new Scope(stack);
+							ILocalScope scope = new LocalScope(stack);
 							return new Definition[]{new Definition(def.o1, def.o2, token.getRepresentation(), ast2, scope, module)};
                             
 						}else{
@@ -438,7 +451,7 @@ public class SourceModule extends AbstractModule {
         String tok = rep;
         SourceModule mod = this;
 
-        Tuple<IModule, String> o = nature.getAstManager().findOnImportedMods(nature, rep, this);
+        Tuple3<IModule, String, IToken> o = nature.getAstManager().findOnImportedMods(nature, rep, this);
         
         if(o != null && o.o1 instanceof SourceModule){
             mod =  (SourceModule) o.o1;
@@ -450,28 +463,31 @@ public class SourceModule extends AbstractModule {
             if (tok == null || tok.length() == 0 ){
                 return new Definition[]{new Definition(1,1,"",null,null,o.o1)};
             }else{
-                return (Definition[]) o.o1.findDefinition(tok, 0, 0, nature, lFindInfo);
+                return (Definition[]) o.o1.findDefinition(state.getCopyWithActTok(tok), 0, 0, nature, lFindInfo);
             }
         }
         
         //mod == this if we are now checking the globals (or maybe not)...heheheh
-        findDefinitionsFromModAndTok(nature, toRet, visitor.moduleImported, mod, tok);
+        ICompletionState copy = state.getCopy();
+        copy.setActivationToken(tok);
+        try{
+        	state.checkFindDefinitionMemory(mod, tok);
+        	findDefinitionsFromModAndTok(nature, toRet, visitor.moduleImported, mod, copy);
+        }catch(CompletionRecursionException e){
+        	//ignore (will return what we've got so far)
+        }
             
         return toRet.toArray(new Definition[0]);
     }
 
     /**
-     * 
-     * @param nature
-     * @param toRet used to return the values
-     * @param visitor
-     * @param mod
-     * @param tok
+     * Finds the definitions for some module and a token from that module
      */
-	private void findDefinitionsFromModAndTok(IPythonNature nature, ArrayList<Definition> toRet, String moduleImported, SourceModule mod, String tok) {
+	private void findDefinitionsFromModAndTok(IPythonNature nature, ArrayList<Definition> toRet, String moduleImported, SourceModule mod, ICompletionState state) {
+        String tok = state.getActivationToken();
 		if(tok != null){
         	if(tok.length() > 0){
-	            Definition d = mod.findGlobalTokDef(tok, nature);
+	            Definition d = mod.findGlobalTokDef(state.getCopyWithActTok(tok), nature);
 				if(d != null){
 	                toRet.add(d);
 	                
@@ -513,14 +529,15 @@ public class SourceModule extends AbstractModule {
      * @param nature 
      * @return
      */
-    public Definition findGlobalTokDef(String tok, IPythonNature nature) {
+    public Definition findGlobalTokDef(ICompletionState state, IPythonNature nature) {
+        String tok = state.getActivationToken();
     	String[] headAndTail = FullRepIterable.headAndTail(tok);
     	String firstPart = headAndTail[0];
     	String rep = headAndTail[1];
     	
     	IToken[] tokens = null;
     	if(nature != null){
-    		tokens = nature.getAstManager().getCompletionsForModule(this, CompletionState.getEmptyCompletionState(firstPart, nature));
+    		tokens = nature.getAstManager().getCompletionsForModule(this, state.getCopyWithActTok(firstPart), true);
     	}else{
     		tokens = getGlobalTokens();
     	}
@@ -530,16 +547,6 @@ public class SourceModule extends AbstractModule {
                 if(token instanceof SourceToken){
                 	//ok, we found it
                     SimpleNode a = ((SourceToken)token).getAst();
-                    
-                    //this is just to get its scope...
-                    FindScopeVisitor scopeVisitor = new FindScopeVisitor(a.beginLine, a.beginColumn);
-                    if (ast != null){
-                        try {
-                            ast.accept(scopeVisitor);
-                        } catch (Exception e) {
-                            PydevPlugin.log(e);
-                        }
-                    }
                     Tuple<Integer, Integer> def = getLineColForDefinition(a);
                     
                     String parentPackage = token.getParentPackage();
@@ -550,10 +557,26 @@ public class SourceModule extends AbstractModule {
                     		module = mod;
                     	}
                     }
-                    //line, col
-                    return new Definition(def.o1, def.o2, tok, a, scopeVisitor.scope, module);
+                    
+                    
+                    if(module instanceof SourceModule){
+                        //this is just to get its scope...
+                        SourceModule m = (SourceModule) module;
+                        FindScopeVisitor scopeVisitor = new FindScopeVisitor(a.beginLine, a.beginColumn);
+                        if (m.ast != null){
+                            try {
+                                m.ast.accept(scopeVisitor);
+                            } catch (Exception e) {
+                                PydevPlugin.log(e);
+                            }
+                        }
+                        return new Definition(def.o1, def.o2, rep, a, scopeVisitor.scope, module);
+                    }else{
+                        //line, col
+                        return new Definition(def.o1, def.o2, rep, a, new LocalScope(new FastStack<SimpleNode>()), module);
+                    }
                 }else{
-                    CompiledToken comp = (CompiledToken) token;
+                	IToken comp = (IToken) token; //Compiled or Concrete token
                     String parentPackage = comp.getParentPackage();
                     FullRepIterable iterable = new FullRepIterable(parentPackage, true);
                     
@@ -574,7 +597,7 @@ public class SourceModule extends AbstractModule {
                     }
                     finalRep += comp.getRepresentation();
                     try {
-                        IDefinition[] definitions = module.findDefinition(finalRep, -1, -1, nature, new ArrayList<FindInfo>());
+                        IDefinition[] definitions = module.findDefinition(state.getCopyWithActTok(finalRep), -1, -1, nature, new ArrayList<FindInfo>());
                         if(definitions.length > 0){
                             return (Definition) definitions[0];
                         }
@@ -613,25 +636,24 @@ public class SourceModule extends AbstractModule {
                 ast.accept(scopeVisitor);
 	        }
 	        
-	        return scopeVisitor.scope.getLocalTokens(line, col);
+	        return scopeVisitor.scope.getLocalTokens(line, col, false);
         } catch (Exception e) {
             e.printStackTrace();
             return new IToken[0];
         }
     }
 
-    @Override
-    public List<IToken> getLocalImportedModules(int line, int col) {
+    public ILocalScope getLocalScope(int line, int col) {
         try {
             FindScopeVisitor scopeVisitor = new FindScopeVisitor(line, col);
             if (ast != null){
                 ast.accept(scopeVisitor);
             }
             
-            return scopeVisitor.scope.getLocalImportedModules(line, col, name);
+            return scopeVisitor.scope;
         } catch (Exception e) {
             e.printStackTrace();
-            return new ArrayList<IToken>();
+            return null;
         }
     }
     
