@@ -22,6 +22,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.Tuple;
+import org.python.pydev.core.log.Log;
 import org.python.pydev.editor.actions.refactoring.PyRefactorAction.Operation;
 import org.python.pydev.editor.codecompletion.PyCodeCompletion;
 import org.python.pydev.editor.codecompletion.PyCodeCompletionPreferencesPage;
@@ -43,7 +44,7 @@ public abstract class AbstractShell {
     public static final int BUFFER_SIZE = 1024 ;
     public static final int OTHERS_SHELL = 2;
     public static final int COMPLETION_SHELL = 1;
-    protected static final int DEFAULT_SLEEP_BETWEEN_ATTEMPTS = 1000;
+    protected static final int DEFAULT_SLEEP_BETWEEN_ATTEMPTS = 1000; //1sec, so we can make the number of attempts be shown as elapsed in secs
     protected static final int DEBUG_SHELL = -1;
     
     /**
@@ -68,10 +69,13 @@ public abstract class AbstractShell {
      */
     private boolean isInOperation = false;
 
-    private void dbg(Object string, int priority) {
+    private static void dbg(String string, int priority) {
         if(priority <= DEBUG_SHELL){
             System.out.println(string);
         }
+        if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+            Log.toLogFile(string, AbstractShell.class);
+        }
     }
 
     /**
@@ -199,11 +203,21 @@ public abstract class AbstractShell {
      * @throws IOException
      */
     public synchronized static AbstractShell getServerShell(int relatedId, int id) throws IOException, Exception {
+    	AbstractShell pythonShell = null;
     	synchronized(shells){
+    	    if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+    	        Log.toLogFile("Synchronizing on shells...", AbstractShell.class);
+    	    }
+            if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+                Log.toLogFile( "Getting shell relatedId:"+relatedId+" id:"+id, AbstractShell.class);
+            }
 	        Map<Integer, AbstractShell> typeToShell = getTypeToShellFromId(relatedId);
-	        AbstractShell pythonShell = (AbstractShell) typeToShell.get(new Integer(id));
+	        pythonShell = (AbstractShell) typeToShell.get(new Integer(id));
 	        
 	        if(pythonShell == null){
+                if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+                    Log.toLogFile("pythonShell == null", AbstractShell.class);
+                }
 	            if(relatedId == IPythonNature.PYTHON_RELATED){
 	                pythonShell = new PythonShell();
 	            }else if(relatedId == IPythonNature.JYTHON_RELATED){
@@ -211,20 +225,22 @@ public abstract class AbstractShell {
 	            }else{
 	                throw new RuntimeException("unknown related id");
 	            }
-	            synchronized(pythonShell){
-	            	pythonShell.startIt(); //first start it
-	            }
+                if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+                    Log.toLogFile("pythonShell.startIt()", AbstractShell.class);
+                    Log.addLogLevel();
+                }
+            	pythonShell.startIt(); //first start it
+            	if(PyCodeCompletion.DEBUG_CODE_COMPLETION){
+            	    Log.remLogLevel();
+            	    Log.toLogFile("Finished pythonShell.startIt()", AbstractShell.class);
+            	}
 	            
 	            //then make it accessible
 	            typeToShell.put(new Integer(id), pythonShell);
 	        }
             
-            //if the shell is still starting, we will not return it.
-            while(pythonShell.inStart){
-                pythonShell.sleepALittle(200);
-            }
-	        return pythonShell;
     	}
+    	return pythonShell;
     }
 
     /**
@@ -332,13 +348,14 @@ public abstract class AbstractShell {
 				String osName = System.getProperty("os.name");
 				if (process == null) {
 					String msg = "Error creating python process - got null process(" + execMsg + ") - os:" + osName;
+                    dbg(msg, 1);
                     PydevPlugin.log(msg);
 					throw new CoreException(PydevPlugin.makeStatus(IStatus.ERROR, msg, new Exception(msg)));
 				}
 				try {
 					int exitVal = process.exitValue(); //should throw exception saying that it still is not terminated...
-					String msg = "Error creating python process - exited before creating sockets - exitValue = ("
-							+ exitVal + ")(" + execMsg + ") - os:" + osName;
+					String msg = "Error creating python process - exited before creating sockets - exitValue = ("+ exitVal + ")(" + execMsg + ") - os:" + osName;
+					dbg(msg, 1);
 					PydevPlugin.log(msg);
 					throw new CoreException(PydevPlugin.makeStatus(IStatus.ERROR, msg, new Exception(msg)));
 				} catch (IllegalThreadStateException e2) { //this is ok
@@ -358,6 +375,7 @@ public abstract class AbstractShell {
 				int maxAttempts = PyCodeCompletionPreferencesPage.getNumberOfConnectionAttempts();
 				while (!connected && attempts < maxAttempts && !finishedForGood) {
 					attempts += 1;
+					dbg("connecting attept..."+attempts,1);
 					try {
 						if (socketToWrite == null || socketToWrite.isConnected() == false) {
 							socketToWrite = new Socket("127.0.0.1", pWrite); //we should write in this port
@@ -375,12 +393,18 @@ public abstract class AbstractShell {
 						}
 					} catch (IOException e1) {
 						if (socketToWrite != null && socketToWrite.isConnected() == true) {
-							PydevPlugin.log(IStatus.ERROR, "Attempt: " + attempts + " of " + maxAttempts
-									+ " failed, trying again...(socketToWrite already binded)", e1);
+							String msg = "Attempt: " + attempts + " of " + maxAttempts + 
+                            " failed, trying again...(socketToWrite already binded)";
+                            
+							dbg(msg,1);
+                            PydevPlugin.log(IStatus.ERROR, msg, e1);
 						}
 						if (socketToWrite != null && !socketToWrite.isConnected() == true) {
-						    PydevPlugin.log(IStatus.ERROR, "Attempt: " + attempts + " of " + maxAttempts
-						            + " failed, trying again...(socketToWrite still not binded)", e1);
+						    String msg = "Attempt: " + attempts + " of " + maxAttempts +
+                            " failed, trying again...(socketToWrite still not binded)";
+                            
+						    dbg(msg,1);
+                            PydevPlugin.log(IStatus.ERROR, msg, e1);
 						}
 					}
 
@@ -405,8 +429,11 @@ public abstract class AbstractShell {
 					}
 
 					String output = getProcessOutput();
-					Exception exception = new Exception("Error connecting to python process (" + execMsg + ") "
-							+ isAlive + " the output of the process is: " + output);
+					String msg = "Error connecting to python process (" + execMsg + ") " +
+                    isAlive + " the output of the process is: " + output;
+                    
+                    Exception exception = new Exception(msg);
+                    dbg(msg, 1);
                     PydevPlugin.log(exception);
 					throw exception;
 				}
@@ -860,7 +887,7 @@ public abstract class AbstractShell {
      * @param token the token we are looking for
      * @return the file where the token was defined, its line and its column (or null if it was not found)
      */
-    public Tuple<String[],int []> getLineCol(String moduleName, String token, List pythonpath) {
+    public synchronized Tuple<String[],int []> getLineCol(String moduleName, String token, List pythonpath) {
         while(isInOperation){
             sleepALittle(100);
         }
