@@ -15,10 +15,10 @@ import org.eclipse.swt.graphics.Image;
 import org.python.pydev.core.IPythonNature;
 import org.python.pydev.core.bundle.ImageCache;
 import org.python.pydev.core.docutils.PySelection;
+import org.python.pydev.core.docutils.StringUtils;
 import org.python.pydev.editor.PyEdit;
 import org.python.pydev.editor.actions.PyAction;
 import org.python.pydev.editor.codecompletion.IPyCompletionProposal;
-import org.python.pydev.editor.codecompletion.PyCompletionProposal;
 import org.python.pydev.ui.UIConstants;
 
 /**
@@ -62,7 +62,7 @@ public class AssistAssign implements IAssistProps {
         //					 |result| = 1+1
         //					 self.|result| = 1+1
 
-        String callName = getTokToAssign(ps);
+        String callName = getTokToAssign(ps, sel);
 
         if(callName.length() > 0){
             //all that just to change first char to lower case.
@@ -79,11 +79,11 @@ public class AssistAssign implements IAssistProps {
 
         int firstCharPosition = PySelection.getFirstCharPosition(ps.getDoc(), ps.getAbsoluteCursorOffset());
         callName += " = ";
-        l.add(new PyCompletionProposal(callName, firstCharPosition, 0, 0, getImage(imageCache, UIConstants.ASSIST_ASSIGN_TO_LOCAL),
-                "Assign to local ("+tok+")", null, null, IPyCompletionProposal.PRIORITY_DEFAULT));
+        l.add(new AssistAssignCompletionProposal(callName, firstCharPosition, 0, 0, getImage(imageCache, UIConstants.ASSIST_ASSIGN_TO_LOCAL),
+                "Assign to local ("+tok+")", null, null, IPyCompletionProposal.PRIORITY_DEFAULT, edit));
         
-        l.add(new PyCompletionProposal("self." + callName, firstCharPosition, 0, 5, getImage(imageCache,UIConstants.ASSIST_ASSIGN_TO_CLASS),
-                "Assign to field (self."+tok+")", null, null, IPyCompletionProposal.PRIORITY_DEFAULT));
+        l.add(new AssistAssignCompletionProposal("self." + callName, firstCharPosition, 0, 5, getImage(imageCache,UIConstants.ASSIST_ASSIGN_TO_CLASS),
+                "Assign to field (self."+tok+")", null, null, IPyCompletionProposal.PRIORITY_DEFAULT, edit));
         return l;
     }
 
@@ -101,7 +101,7 @@ public class AssistAssign implements IAssistProps {
                 return false;
 
             String eqReplaced = sel.replaceAll("==", "");
-            if (eqReplaced.indexOf("=") != -1){
+            if (eqReplaced.indexOf("=") != -1){ //we have some equal
                 //ok, make analysis taking into account the first parentesis
                 if(eqReplaced.indexOf('(') == -1){
                     return false;
@@ -120,15 +120,16 @@ public class AssistAssign implements IAssistProps {
             
             
         } catch (BadLocationException e) {
+            return false;
         }
-        return false;
+        return true;
     }
 
     /**
      * @param ps
      * @return
      */ 
-    private String getTokToAssign(PySelection ps) {
+    private String getTokToAssign(PySelection ps, String sel) {
         String beforeParentesisTok = PyAction.getBeforeParentesisTok(ps);
         if(beforeParentesisTok.length() > 0){
             return beforeParentesisTok;
@@ -146,6 +147,11 @@ public class AssistAssign implements IAssistProps {
                 callName += string.charAt(j);
             }
         }
+        if(callName.length() == 0){
+            if(StringUtils.isSingleWord(sel.trim())){
+                return sel.trim();
+            }
+        }
         return callName;
     }
 
