@@ -5,7 +5,7 @@
  */
 package org.python.pydev.editor.model;
 
-import org.python.parser.SimpleNode;
+import org.python.pydev.parser.jython.SimpleNode;
 
 /**
  * PyEdit will broadcast model changes to IModelListeners.
@@ -16,7 +16,6 @@ public interface IModelListener {
 	/**
 	 * every time document gets parsed, it generates a new parse tree
 	 * @param root - the root of the new model
-	 * @param root2
 	 */
-	void modelChanged(AbstractNode root, SimpleNode root2);
+	void modelChanged(SimpleNode root);
 }
