@@ -21,7 +21,6 @@ import org.eclipse.core.resources.IProjectNature;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IResourceVisitor;
 import org.eclipse.core.resources.IWorkspace;
-import org.eclipse.core.resources.IWorkspaceRoot;
 import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
@@ -83,8 +82,6 @@ import org.python.pydev.ui.interpreters.PythonInterpreterManager;
  * The main plugin class - initialized on startup - has resource bundle for internationalization - has preferences
  */
 public class PydevPlugin extends AbstractUIPlugin implements Preferences.IPropertyChangeListener {
-	private static boolean DEBUG = false;
-	
 	
     // ----------------- SINGLETON THINGS -----------------------------
     public static IBundleInfo info;
@@ -111,7 +108,7 @@ public class PydevPlugin extends AbstractUIPlugin implements Preferences.IProper
     		try {
     			Thread.sleep(100);
     		} catch (Exception e) {
-    			e.printStackTrace();
+    			//e.printStackTrace();
     		}
     	}
     	return pythonInterpreterManager;
