@@ -68,11 +68,6 @@ public class PythonNature implements IPythonNature {
      */
     public static final String BUILDER_ID = "org.python.pydev.PyDevBuilder";
     
-    /**
-     * constant that stores the name of the python version we are using for the project with this nature
-     */
-    private static final QualifiedName PYTHON_PROJECT_VERSION = new QualifiedName(PydevPlugin.getPluginID(), "PYTHON_PROJECT_VERSION");
-    
     /**
      * Project associated with this nature.
      */
@@ -98,6 +93,11 @@ public class PythonNature implements IPythonNature {
      */
     private IPythonPathNature pythonPathNature = new PythonPathNature();
     
+    /**
+     * Used to actually store settings for the pythonpath
+     */
+    private PythonNatureStore pythonNatureStore = new PythonNatureStore();
+    
     /**
      * This is used to keep the builtin completions
      */
@@ -108,6 +108,19 @@ public class PythonNature implements IPythonNature {
      */
     private IModule builtinMod;
 
+    
+    /**
+     * constant that stores the name of the python version we are using for the project with this nature
+     */
+    private static QualifiedName pythonProjectVersion = null;
+    static QualifiedName getPythonProjectVersionQualifiedName() {
+        if(pythonProjectVersion == null){
+            //we need to do this because the plugin ID may not be known on 'static' time
+            pythonProjectVersion = new QualifiedName(PydevPlugin.getPluginID(), "PYTHON_PROJECT_VERSION");
+        }
+        return pythonProjectVersion;
+    }
+
     /**
      * This method is called only when the project has the nature added..
      * 
@@ -139,6 +152,7 @@ public class PythonNature implements IPythonNature {
     public void setProject(IProject project) {
         this.project = project;
         this.pythonPathNature.setProject(project);
+        this.getStore().setProject(project);
     }
 
     public static synchronized IPythonNature addNature(IEditorInput element) {
@@ -249,8 +263,7 @@ public class PythonNature implements IPythonNature {
 								}
 
 								if (astManager != null) {
-									List<IInterpreterObserver> participants = ExtensionHelper
-											.getParticipants(ExtensionHelper.PYDEV_INTERPRETER_OBSERVER);
+									List<IInterpreterObserver> participants = ExtensionHelper.getParticipants(ExtensionHelper.PYDEV_INTERPRETER_OBSERVER);
 									for (IInterpreterObserver observer : participants) {
 										try {
 											observer.notifyNatureRecreated(nature, jobProgressComunicator);
@@ -287,7 +300,7 @@ public class PythonNature implements IPythonNature {
     }
 
 
-    /**
+	/**
      * Returns the directory that should store completions.
      * 
      * @param p
@@ -372,6 +385,7 @@ public class PythonNature implements IPythonNature {
                 }
 
                 initializationFinished = true;
+                PythonNatureListenersManager.notifyPythonPathRebuilt(project, nature.pythonPathNature.getCompleteProjectPythonPath());
                 //end task
                 jobProgressComunicator.done();
                 return Status.OK_STATUS;
@@ -469,23 +483,34 @@ public class PythonNature implements IPythonNature {
     private String persistentProperty = null;
     
     /**
+     * Returns the Python version of the Project. It dynamically recomputes the version from the PythonNatureStore's value
+     * because it might have changed on disk (e.g. a repository update).
      * @return the python version for the project
      * @throws CoreException 
      */
     public String getVersion() throws CoreException {
         if(project != null){
-        	if(persistentProperty == null){
-	            persistentProperty = project.getPersistentProperty(PYTHON_PROJECT_VERSION);
-	            if(persistentProperty == null){ //there is no such property set (let's set it to the default)
-	                String defaultVersion = getDefaultVersion();
-	                setVersion(defaultVersion);
-	                persistentProperty = defaultVersion;
+            String storeVersion = getStore().getPropertyFromXml(getPythonProjectVersionQualifiedName());
+        	if (persistentProperty == null) {
+	            if(storeVersion == null){ //there is no such property set (let's set it to the default)
+	                storeVersion = getDefaultVersion();
 	            }
-        	}
+                setVersion(storeVersion);
+        	} else if (!persistentProperty.equals(storeVersion)){
+                if (storeVersion == null) {
+                    // Something very bad happened in the store, log it
+                    PydevPlugin.log("Possible PythonNatureStore corruption, storeVersion == null but persistentProperty != null; storing persistentProperty");
+                    getStore().setPropertyToXml(getPythonProjectVersionQualifiedName(), persistentProperty, true);
+                } else {
+                    // The storeVersion has changed for some reason
+                    setVersion(storeVersion);
+                }
+            }
             return persistentProperty;
         }
         return null;
     }
+    
     /**
      * set the project version given the constants provided
      * @throws CoreException 
@@ -494,7 +519,7 @@ public class PythonNature implements IPythonNature {
 		clearCaches();
         if(project != null){
         	this.persistentProperty = version;
-            project.setPersistentProperty(PYTHON_PROJECT_VERSION, version);
+            getStore().setPropertyToXml(getPythonProjectVersionQualifiedName(), version, true);
         }
     }
 
@@ -666,6 +691,25 @@ public class PythonNature implements IPythonNature {
         return ret;
     }
 
+    /**
+     * @return the version of the grammar as defined in IPythonNature.GRAMMAR_PYTHON...
+     */
+    public int getGrammarVersion() {
+        try {
+            if(getVersion().equals(PYTHON_VERSION_2_5)){
+                return GRAMMAR_PYTHON_VERSION_2_5;
+            }else{
+                return GRAMMAR_PYTHON_VERSION_2_4;
+            }
+        } catch (CoreException e) {
+            throw new RuntimeException(e);
+        }
+    }
+    
+    protected PythonNatureStore getStore(){
+    	return pythonNatureStore;
+    }
+
 }
 
 
