@@ -7,9 +7,7 @@ import java.io.File;
 import java.io.IOException;
 
 import org.eclipse.core.resources.IProject;
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.python.copiedfromeclipsesrc.JavaVmLocationFinder;
 import org.python.pydev.core.IInterpreterManager;
@@ -18,67 +16,6 @@ import org.python.pydev.plugin.PydevPlugin;
 import org.python.pydev.ui.pythonpathconf.InterpreterInfo;
 
 public class SimpleJythonRunner extends SimpleRunner{
-    /**
-     * This is the method that actually does the running (all others are just 'shortcuts' to this one).
-     * 
-     * @param executionString this is the string that will be executed
-     * @param workingDir this is the directory where the execution will happen
-     * @param project this is the project that is related to the run (it is used to get the environment for the shell we are going to
-     * execute with the correct pythonpath environment variable).
-     * @param monitor this is the monitor used to communicate the progress to the user
-     * 
-     * @return the string that is the output of the process (stdout).
-     */
-    public Tuple<String,String> runAndGetOutput(String executionString, File workingDir, IProject project, IProgressMonitor monitor) {
-        monitor.setTaskName("Executing: "+executionString);
-        monitor.worked(5);
-        Process process = null;
-        try {
-            monitor.setTaskName("Making pythonpath environment...");
-            String[] envp = getEnvironment(project);
-            monitor.setTaskName("Making exec.");
-            process = Runtime.getRuntime().exec(executionString, envp, workingDir);
-        } catch (Exception e) {
-            throw new RuntimeException(e);
-        }
-
-        if (process != null) {
-
-            try {
-                process.getOutputStream().close(); //we won't write to it...
-            } catch (IOException e2) {
-            }
-
-            monitor.setTaskName("Reading output...");
-            monitor.worked(5);
-            ThreadStreamReader std = new ThreadStreamReader(process.getInputStream());
-            ThreadStreamReader err = new ThreadStreamReader(process.getErrorStream());
-
-            std.start();
-            err.start();
-            
-            
-            try {
-                monitor.setTaskName("Waiting for process to finish.");
-                monitor.worked(5);
-                process.waitFor(); //wait until the process completion.
-            } catch (InterruptedException e1) {
-                throw new RuntimeException(e1);
-            }
-
-            return new Tuple<String,String>(std.contents.toString(), err.contents.toString());
-            
-        } else {
-            try {
-                throw new CoreException(PydevPlugin.makeStatus(IStatus.ERROR, "Error creating python process - got null process("
-                        + executionString + ")", new Exception("Error creating python process - got null process.")));
-            } catch (CoreException e) {
-                PydevPlugin.log(IStatus.ERROR, e.getMessage(), e);
-            }
-
-        }
-        return new Tuple<String,String>("", "Error creating python process - got null process("+ executionString + ")"); //no output
-    }
 
     public Tuple<String,String> runAndGetOutputWithJar(String script, String jythonJar, String args, File workingDir, IProject project, IProgressMonitor monitor) {
         //"C:\Program Files\Java\jdk1.5.0_04\bin\java.exe" "-Dpython.home=C:\bin\jython21" 
@@ -149,9 +86,25 @@ public class SimpleJythonRunner extends SimpleRunner{
         }
         
         
+        //may have the dir or be null
+        String cacheDir = null;
+        try{
+            cacheDir = PydevPlugin.getChainedPrefStore().getString(IInterpreterManager.JYTHON_CACHE_DIR);
+        }catch(NullPointerException e){
+            //this may happen while running the tests... it should be ok.
+            cacheDir = null;
+        }
+        if(cacheDir != null && cacheDir.trim().length()==0){
+            cacheDir = null;
+        }
+        if(cacheDir != null){
+            cacheDir = "-Dpython.cachedir="+ cacheDir.trim();
+            
+        }
         String[] s = new String[]{
             javaLoc ,
-            "-Dpython.path="+ jythonPath.toString(), 
+            cacheDir,
+            "-Dpython.path="+ jythonPath.toString(),
             "-classpath",
             jythonJar+pathSeparator+jythonPath,
             "org.python.util.jython",
