@@ -21,10 +21,12 @@ public class UIConstants {
     public static final String COMPLETION_PACKAGE_ICON = "icons/package_obj.gif";
 	public static final String COMPLETION_TEMPLATE = "icons/template.gif";
     public static final String COMMENT = "icons/python_comment.png";
+    public static final String COMMENT_BLACK = "icons/python_comment_black.png";
 
 // Actions
 	public static final String ALPHA_SORT = "icons/alphab_sort_co.gif";
 	public static final String COLLAPSE_ALL = "icons/collapseall.gif";
+	public static final String EXPAND_ALL = "icons/expand.gif";
 	
 //file content
 	public static final String FILE_ICON = "icons/file.gif";
