@@ -120,6 +120,23 @@ public abstract class AbstractInterpreterManager implements IInterpreterManager
         return interpretersFromPersistedString;
     }
     
+    /**
+     * @see org.python.pydev.core.IInterpreterManager#hasInfoOnInterpreter(java.lang.String)
+     */
+    public boolean hasInfoOnInterpreter(String interpreter) {
+        if(interpreter == null){
+            return false;
+        }
+        interpreter = interpreter.toLowerCase();
+        String[] interpreters = getInterpreters();
+        for (String str : interpreters) {
+            if(str.toLowerCase().equals(interpreter)){
+                return true;
+            }
+        }
+        return false;
+    }
+    
     /**
      * @see org.python.pydev.core.IInterpreterManager#getDefaultInterpreterInfo(org.eclipse.core.runtime.IProgressMonitor)
      */
@@ -201,9 +218,12 @@ public abstract class AbstractInterpreterManager implements IInterpreterManager
     }
 
     /**
+     * Called when an interpreter should be added.
+     * 
      * @see org.python.pydev.core.IInterpreterManager#addInterpreter(java.lang.String)
      */
     public String addInterpreter(String executable, IProgressMonitor monitor) {
+        exeToInfo.remove(executable); //always clear it
         InterpreterInfo info = getInterpreterInfo(executable, monitor);
         return info.executableOrJar;
     }
