@@ -12,8 +12,10 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.Iterator;
 
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.ProgressMonitorWrapper;
+import org.eclipse.jface.dialogs.ErrorDialog;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.InputDialog;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
@@ -197,22 +199,34 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
         changed = true;
     }
     
+    protected void adjustForNumColumns(int numColumns) {
+        super.adjustForNumColumns(numColumns);
+        ((GridData) l1.getLayoutData()).horizontalSpan = numColumns;
+        ((GridData) tree.getLayoutData()).horizontalSpan = numColumns-1;
+        ((GridData) boxSystem.getLayoutData()).horizontalSpan = 1;
+        ((GridData) l2.getLayoutData()).horizontalSpan = numColumns;
+        ((GridData) listBuiltins.getLayoutData()).horizontalSpan = numColumns-1;
+        ((GridData) box.getLayoutData()).horizontalSpan = 1;
+    }
+    
+    Label l1;
+    Label l2;
+    
     /**
      * @see org.eclipse.jface.preference.ListEditor#doFillIntoGrid(org.eclipse.swt.widgets.Composite, int)
      */
     protected void doFillIntoGrid(Composite parent, int numColumns) {
         super.doFillIntoGrid(parent, numColumns);
         
-    	Label l1 = new Label(parent, SWT.None);
+    	l1 = new Label(parent, SWT.None);
     	l1.setText("System PYTHONPATH");
     	GridData gd = new GridData();
     	gd.horizontalSpan = numColumns;
     	l1.setLayoutData(gd);
 
     	//the tree
-        Tree tree = getTreeLibsControl(parent);
+        tree = getTreeLibsControl(parent);
     	gd = new GridData();
-    	gd.horizontalSpan = numColumns - 1;
         gd.horizontalAlignment = SWT.FILL;
         gd.verticalAlignment = SWT.FILL;
         gd.grabExcessVerticalSpace = true;
@@ -222,20 +236,17 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
         Composite control = getButtonBoxControlSystem(parent);
     	gd = new GridData();
     	gd.verticalAlignment = GridData.BEGINNING;
-    	gd.horizontalSpan = numColumns - 1;
     	control.setLayoutData(gd);
 
         //label
-    	Label l2 = new Label(parent, SWT.None);
+    	l2 = new Label(parent, SWT.None);
     	l2.setText("Forced builtin libs (check http://pydev.sf.net/faq.html for more info).");
     	gd = new GridData();
-    	gd.horizontalSpan = numColumns;
     	l2.setLayoutData(gd);
 
         //the list with the builtins
     	List list = getBuiltinsListControl(parent);
         gd = new GridData();
-        gd.horizontalSpan = numColumns - 1;
         gd.horizontalAlignment = SWT.FILL;
         gd.grabExcessHorizontalSpace = false;
         gd.heightHint = 100;
@@ -245,7 +256,6 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
     	control = getButtonBoxControlOthers(parent);
         gd = new GridData();
         gd.verticalAlignment = GridData.BEGINNING;
-        gd.horizontalSpan = numColumns - 1;
         control.setLayoutData(gd);
     }
     /**
@@ -350,6 +360,9 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
         return selectionListenerOthers;
     }
 
+    private static String lastDirectoryDialogPath = null;
+    private static String lastFileDialogPath = null;
+    
     /**
      * Returns this field editor's selection listener. The listener is created if nessessary.
      * 
@@ -367,16 +380,20 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
                         Widget widget = event.widget;
                         if (widget == addBtSystemFolder) {
                             DirectoryDialog dialog = new DirectoryDialog(getShell());
+                            dialog.setFilterPath(lastDirectoryDialogPath);
                             String filePath = dialog.open();
                             if(filePath != null){
+                                lastDirectoryDialogPath = filePath;
                                 info.libs.add(filePath);
                                 changed = true;
                             }
                             
                         } else if (widget == addBtSystemJar) {
                             FileDialog dialog = new FileDialog(getShell());
+                            dialog.setFilterPath(lastFileDialogPath);
                             String filePath = dialog.open();
                             if(filePath != null){
+                                lastFileDialogPath = filePath;
                                 info.libs.add(filePath);
                                 info.dllLibs.add(filePath);
                                 changed = true;
@@ -570,6 +587,19 @@ public abstract class AbstractInterpreterEditor extends PythonListEditor {
 				if (operation.e != null) {
 					logger.println("- Some error happened while getting info on the interpreter:");
 					operation.e.printStackTrace(logger);
+                    
+                    String errorMsg = "Some error happened while getting info on the interpreter.\n\n" +
+                                "Common reasons include:\n\n" +
+                                "- Specifying an invalid interpreter" +
+                                "(usually a link to the actual interpreter on Mac or Linux)\n" +
+                                "- Having spaces in your Eclipse installation path.";
+                    //show the user a message (so that it does not fail silently)...
+                    ErrorDialog.openError(this.getShell(), "Error getting info on interpreter", 
+                            errorMsg, 
+                            PydevPlugin.makeStatus(IStatus.ERROR, "Check your error log for more details.\n\n" +
+                                "More info can also be found at the bug report: http://sourceforge.net/tracker/index.php?func=detail&aid=1523582&group_id=85796&atid=577329", 
+                            operation.e));
+                    
 					throw operation.e;
 				}
 
