@@ -26,7 +26,7 @@ public class PyAutoIndentStrategyTest extends TestCase {
         try {
             PyAutoIndentStrategyTest s = new PyAutoIndentStrategyTest("testt");
             s.setUp();
-            s.testTab();
+            s.testNewLineWithNewWithConstruct();
             s.tearDown();
     		junit.textui.TestRunner.run(PyAutoIndentStrategyTest.class);
         } catch (Throwable e) {
@@ -57,6 +57,19 @@ public class PyAutoIndentStrategyTest extends TestCase {
         strategy = new PyAutoIndentStrategy();
     }
     
+    
+    public void testNewLineWithNewWithConstruct() {
+        strategy.setIndentPrefs(new TestIndentPrefs(true, 4));
+        String str = "" +
+        "class C:\n" +
+        "    with a:" +
+        "";
+        final Document doc = new Document(str);
+        DocCmd docCmd = new DocCmd(doc.getLength(), 0, "\n");
+        strategy.customizeDocumentCommand(doc, docCmd);
+        assertEquals("\n        ", docCmd.text); 
+    }
+
     public void testTab() {
         strategy.setIndentPrefs(new TestIndentPrefs(true, 4));
         String str = 
@@ -67,6 +80,19 @@ public class PyAutoIndentStrategyTest extends TestCase {
         assertEquals("    ", docCmd.text);
     }
     
+    public void testTab2() {
+        strategy.setIndentPrefs(new TestIndentPrefs(true, 4));
+        String str = 
+            "class Foo:\n"+
+            "    def m"+
+        "";
+        DocCmd docCmd = new DocCmd(str.length()-"    def m".length(), 4, "\t");
+        Document document = new Document(str);
+        strategy.customizeDocumentCommand(document, docCmd);
+        assertEquals("    ", docCmd.text); 
+        assertEquals(str, document.get()); //as we already have a selection, nothing should be deleted
+    }
+    
     public void testSpaces() {
         strategy.setIndentPrefs(new TestIndentPrefs(true, 4));
         DocCmd docCmd = new DocCmd(0, 0, "\t");
