@@ -27,6 +27,8 @@ import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.QualifiedName;
 import org.eclipse.core.runtime.content.IContentTypeMatcher;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
+import org.python.pydev.core.IPythonNature;
+import org.python.pydev.plugin.nature.FileStub2;
 import org.python.pydev.plugin.nature.PythonNature;
 
 public class ProjectStub implements IProject {
@@ -77,8 +79,11 @@ public class ProjectStub implements IProject {
     }
 
     public IFile getFile(String name) {
-        throw new RuntimeException("not impl");
+        fileStub = new FileStub2(name);
+        return fileStub;
     }
+    
+    public FileStub2 fileStub;
 
     public IFolder getFolder(String name) {
         throw new RuntimeException("not impl");
@@ -281,6 +286,15 @@ public class ProjectStub implements IProject {
     }
 
     public String getPersistentProperty(QualifiedName key) throws CoreException {
+        if(key.getLocalName().equals("PYTHON_PROJECT_VERSION")){
+            return IPythonNature.PYTHON_VERSION_2_5;//for tests, always the latest version
+        }
+        if(key.getLocalName().equals("PROJECT_SOURCE_PATH")){
+            return this.path;
+        }
+        if(key.getLocalName().equals("PROJECT_EXTERNAL_SOURCE_PATH")){
+            return "";
+        }
         throw new RuntimeException("not impl");
     }
 
@@ -381,6 +395,9 @@ public class ProjectStub implements IProject {
     }
 
     public void setPersistentProperty(QualifiedName key, String value) throws CoreException {
+        if(value == null){
+            return;
+        }
         throw new RuntimeException("not impl");
     }
 
