@@ -21,6 +21,25 @@ import org.python.pydev.editor.codecompletion.revisited.modules.CompiledModule;
  */
 public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
+    public static void main(String[] args) {
+        
+        try {
+            PythonPathHelperTest test = new PythonPathHelperTest();
+            test.setUp();
+            test.testResolvePath();
+            test.tearDown();
+            System.out.println("Finished");
+            junit.textui.TestRunner.run(PythonPathHelperTest.class);
+        } catch (Exception e) {
+            e.printStackTrace();
+        } catch(Error e){
+            e.printStackTrace();
+        } catch(Throwable e){
+            e.printStackTrace();
+        }
+    }
+    
+    
     
 	public String qual = "";
 	public String token = "";
@@ -50,8 +69,9 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
     
     public void testResolvePath(){
         PythonPathHelper helper = new PythonPathHelper();
-        helper.setPythonPath(TestDependent.PYTHON_INSTALL+"Lib| "+TestDependent.PYTHON_INSTALL+"Lib/site-packages|"+
-                TestDependent.TEST_PYSRC_LOC);
+        String path = TestDependent.PYTHON_INSTALL+"Lib| "+TestDependent.PYTHON_INSTALL+"Lib/site-packages|"+
+		                TestDependent.TEST_PYSRC_LOC;
+		helper.setPythonPath(path);
         
         assertEquals("unittest",helper.resolveModule(TestDependent.PYTHON_INSTALL+"Lib/unittest.py"));
         assertEquals("compiler.ast",helper.resolveModule(TestDependent.PYTHON_INSTALL+"Lib/compiler/ast.py"));
@@ -80,7 +100,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 		
         IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature, "");
         comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
         assertEquals(9, comps.length);
 
@@ -106,7 +126,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 		
         IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
         ICodeCompletionASTManager a = (ICodeCompletionASTManager)nature.getAstManager();
         comps = a.getCompletionsForToken(doc, state);
         assertFalse(comps.length == 0);
@@ -125,7 +145,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 		
         IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
         ICodeCompletionASTManager a = (ICodeCompletionASTManager)nature.getAstManager();
         comps = a.getCompletionsForToken(doc, state);
         assertEquals(0, comps.length);
@@ -146,7 +166,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
 		IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
 		comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
 		assertTrue(comps.length > 5);
         ASTManagerTest.assertIsIn("assertEquals", comps);
@@ -167,7 +187,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
 		IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
 		comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
 		ASTManagerTest.assertIsIn("SetWidget", comps);
         ASTManagerTest.assertIsIn("assertEquals", comps);
@@ -189,7 +209,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
 		IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
 		comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
 		assertTrue(comps.length > 5);
         ASTManagerTest.assertIsIn("assertEquals", comps);
@@ -210,7 +230,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 		
         IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
         comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
         assertEquals(9, comps.length);
 
@@ -237,7 +257,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
 		IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
 		comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
 		assertTrue(comps.length > 5);
         ASTManagerTest.assertIsIn("assertEquals", comps);
@@ -259,7 +279,7 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
 
 		IToken[] comps = null;
         Document doc = new Document(sDoc);
-        ICompletionState state = new CompletionState(line,col, token, nature);
+        ICompletionState state = new CompletionState(line,col, token, nature,"");
 		comps = ((ICodeCompletionASTManager)nature.getAstManager()).getCompletionsForToken(doc, state);
         ASTManagerTest.assertIsIn("test1", comps);
         ASTManagerTest.assertIsIn("test2", comps);
@@ -309,24 +329,6 @@ public class PythonPathHelperTest extends CodeCompletionTestsBase {
         String encoding = REF.getPythonFileEncoding(new File(loc));
         assertEquals("utf-8", encoding.toLowerCase());
     }
-
-    public static void main(String[] args) {
-        
-        try {
-            PythonPathHelperTest test = new PythonPathHelperTest();
-            test.setUp();
-            test.testGetEncoding2();
-            test.tearDown();
-            System.out.println("Finished");
-            junit.textui.TestRunner.run(PythonPathHelperTest.class);
-        } catch (Exception e) {
-            e.printStackTrace();
-        } catch(Error e){
-            e.printStackTrace();
-        } catch(Throwable e){
-            e.printStackTrace();
-        }
-    }
 }
 
 
