@@ -13,7 +13,7 @@ import junit.framework.TestCase;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.Path;
 import org.python.pydev.core.TestDependent;
-import org.python.pydev.plugin.BundleInfo;
+import org.python.pydev.plugin.PydevPlugin;
 import org.python.pydev.runners.SimplePythonRunner;
 import org.python.pydev.ui.BundleInfoStub;
 
@@ -31,7 +31,7 @@ public class SimplePythonRunnerTest extends TestCase {
      */
     protected void setUp() throws Exception {
         super.setUp();
-        BundleInfo.setBundleInfo(new BundleInfoStub());
+        PydevPlugin.setBundleInfo(new BundleInfoStub());
     }
 
     /*
@@ -48,7 +48,7 @@ public class SimplePythonRunnerTest extends TestCase {
      */
     public void testEnv() throws CoreException, IOException {
         
-        File relativePath = BundleInfo.getBundleInfo().getRelativePath(new Path("PySrc/interpreterInfo.py"));
+        File relativePath = PydevPlugin.getBundleInfo().getRelativePath(new Path("PySrc/interpreterInfo.py"));
         String string = new SimplePythonRunner().runAndGetOutput(TestDependent.PYTHON_EXE+" "+relativePath.getCanonicalPath(), null).o1;
         assertNotNull(string);
         //System.out.println(string);
