@@ -6,11 +6,13 @@
 package org.python.pydev.ui;
 
 import java.io.File;
+import java.net.URL;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.python.pydev.core.TestDependent;
-import org.python.pydev.plugin.IBundleInfo;
+import org.python.pydev.core.bundle.IBundleInfo;
+import org.python.pydev.core.bundle.ImageCache;
 
 
 public class BundleInfoStub implements IBundleInfo {
@@ -25,6 +27,9 @@ public class BundleInfoStub implements IBundleInfo {
         if(relative.toString().indexOf("jycompletionserver.py") != -1){
             return new File(TestDependent.TEST_PYDEV_PLUGIN_LOC+"PySrc/jycompletionserver.py");
         }
+        if(relative.toString().indexOf("indent.py") != -1){
+            return new File(TestDependent.TEST_PYDEV_JYTHON_PLUGIN_LOC+"jysrc/indent.py");
+        }
         throw new RuntimeException("Not available info on: "+relative);
     }
 
@@ -33,6 +38,10 @@ public class BundleInfoStub implements IBundleInfo {
     }
 
     public ImageCache getImageCache() {
-        return null;
+        try {
+            return new ImageCache(new URL("file:///" + TestDependent.TEST_PYDEV_PLUGIN_LOC));
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        }
     }
 }
\ No newline at end of file
